# This file is auto-generated by pyrandyos/gui/icons/update_from_spec.py  # noqa: E501
# Do not edit.
ab_testing = 983497
abacus = 988896
abjad_arabic = 987944
abjad_hebrew = 987945
abugida_devanagari = 987946
abugida_thai = 987947
access_point = 983043
access_point_check = 988472
access_point_minus = 988473
access_point_network = 983042
access_point_network_off = 986081
access_point_off = 988433
access_point_plus = 988474
access_point_remove = 988475
account = 983044
account_alert = 983045
account_alert_outline = 985936
account_arrow_down = 989288
account_arrow_down_outline = 989289
account_arrow_left = 985937
account_arrow_left_outline = 985938
account_arrow_right = 985939
account_arrow_right_outline = 985940
account_arrow_up = 989287
account_arrow_up_outline = 989290
account_badge = 989962
account_badge_outline = 989963
account_box = 983046
account_box_multiple = 985396
account_box_multiple_outline = 987146
account_box_outline = 983047
account_cancel = 987871
account_cancel_outline = 987872
account_card = 990116
account_card_outline = 990117
account_cash = 987287
account_cash_outline = 987288
account_check = 983048
account_check_outline = 986082
account_child = 985737
account_child_circle = 985738
account_child_outline = 987336
account_circle = 983049
account_circle_outline = 985941
account_clock = 985942
account_clock_outline = 985943
account_cog = 988016
account_cog_outline = 988017
account_convert = 983050
account_convert_outline = 987905
account_cowboy_hat = 986779
account_cowboy_hat_outline = 989171
account_credit_card = 990118
account_credit_card_outline = 990119
account_details = 984625
account_details_outline = 988018
account_edit = 984764
account_edit_outline = 987131
account_eye = 984096
account_eye_outline = 987771
account_file = 990375
account_file_outline = 990376
account_file_text = 990377
account_file_text_outline = 990378
account_filter = 985398
account_filter_outline = 987037
account_group = 985161
account_group_outline = 985944
account_hard_hat = 984501
account_hard_hat_outline = 989727
account_heart = 985241
account_heart_outline = 986083
account_injury = 989205
account_injury_outline = 989206
account_key = 983051
account_key_outline = 986084
account_lock = 987486
account_lock_open = 989536
account_lock_open_outline = 989537
account_lock_outline = 987487
account_minus = 983053
account_minus_outline = 985836
account_multiple = 983054
account_multiple_check = 985285
account_multiple_check_outline = 987646
account_multiple_minus = 984531
account_multiple_minus_outline = 986085
account_multiple_outline = 983055
account_multiple_plus = 983056
account_multiple_plus_outline = 985088
account_multiple_remove = 987658
account_multiple_remove_outline = 987659
account_music = 985091
account_music_outline = 986345
account_network = 983057
account_network_off = 989937
account_network_off_outline = 989938
account_network_outline = 986086
account_off = 983058
account_off_outline = 986087
account_outline = 983059
account_plus = 983060
account_plus_outline = 985089
account_question = 985945
account_question_outline = 985946
account_reactivate = 988459
account_reactivate_outline = 988460
account_remove = 983061
account_remove_outline = 985837
account_school = 989728
account_school_outline = 989729
account_search = 983062
account_search_outline = 985397
account_settings = 984624
account_settings_outline = 987337
account_star = 983063
account_star_outline = 986088
account_supervisor = 985739
account_supervisor_circle = 985740
account_supervisor_circle_outline = 988396
account_supervisor_outline = 987437
account_switch = 983065
account_switch_outline = 984267
account_sync = 989467
account_sync_outline = 989468
account_tag = 990235
account_tag_outline = 990236
account_tie = 986339
account_tie_hat = 989336
account_tie_hat_outline = 989337
account_tie_outline = 987338
account_tie_voice = 987912
account_tie_voice_off = 987914
account_tie_voice_off_outline = 987915
account_tie_voice_outline = 987913
account_tie_woman = 989836
account_voice = 984523
account_voice_off = 986836
account_wrench = 989338
account_wrench_outline = 989339
adjust = 983066
advertisements = 989482
advertisements_off = 989483
air_conditioner = 983067
air_filter = 986435
air_horn = 986540
air_humidifier = 987289
air_humidifier_off = 988262
air_purifier = 986436
air_purifier_off = 990039
airbag = 986089
airballoon = 983068
airballoon_outline = 987147
airplane = 983069
airplane_alert = 989306
airplane_check = 989307
airplane_clock = 989308
airplane_cog = 989309
airplane_edit = 989310
airplane_landing = 984532
airplane_marker = 989311
airplane_minus = 989312
airplane_off = 983070
airplane_plus = 989313
airplane_remove = 989314
airplane_search = 989315
airplane_settings = 989316
airplane_takeoff = 984533
airport = 985163
alarm = 983072
alarm_bell = 984974
alarm_check = 983073
alarm_light = 984975
alarm_light_off = 988958
alarm_light_off_outline = 988959
alarm_light_outline = 986090
alarm_multiple = 983074
alarm_note = 986737
alarm_note_off = 986738
alarm_off = 983075
alarm_panel = 988612
alarm_panel_outline = 988613
alarm_plus = 983076
alarm_snooze = 984718
album = 983077
alert = 983078
alert_box = 983079
alert_box_outline = 986340
alert_circle = 983080
alert_circle_check = 987629
alert_circle_check_outline = 987630
alert_circle_outline = 984534
alert_decagram = 984765
alert_decagram_outline = 986341
alert_minus = 988347
alert_minus_outline = 988350
alert_octagon = 983081
alert_octagon_outline = 986342
alert_octagram = 984935
alert_octagram_outline = 986343
alert_outline = 983082
alert_plus = 988346
alert_plus_outline = 988349
alert_remove = 988348
alert_remove_outline = 988351
alert_rhombus = 987598
alert_rhombus_outline = 987599
alien = 985242
alien_outline = 987339
align_horizontal_center = 987587
align_horizontal_distribute = 989538
align_horizontal_left = 987586
align_horizontal_right = 987588
align_vertical_bottom = 987589
align_vertical_center = 987590
align_vertical_distribute = 989539
align_vertical_top = 987591
all_inclusive = 984766
all_inclusive_box = 989325
all_inclusive_box_outline = 989326
allergy = 987736
alpha = 983083
alpha_a = 985838
alpha_a_box = 985864
alpha_a_box_outline = 986091
alpha_a_circle = 986092
alpha_a_circle_outline = 986093
alpha_b = 985839
alpha_b_box = 985865
alpha_b_box_outline = 986094
alpha_b_circle = 986095
alpha_b_circle_outline = 986096
alpha_c = 985840
alpha_c_box = 985866
alpha_c_box_outline = 986097
alpha_c_circle = 986098
alpha_c_circle_outline = 986099
alpha_d = 985841
alpha_d_box = 985867
alpha_d_box_outline = 986100
alpha_d_circle = 986101
alpha_d_circle_outline = 986102
alpha_e = 985842
alpha_e_box = 985868
alpha_e_box_outline = 986103
alpha_e_circle = 986104
alpha_e_circle_outline = 986105
alpha_f = 985843
alpha_f_box = 985869
alpha_f_box_outline = 986106
alpha_f_circle = 986107
alpha_f_circle_outline = 986108
alpha_g = 985844
alpha_g_box = 985870
alpha_g_box_outline = 986109
alpha_g_circle = 986110
alpha_g_circle_outline = 986111
alpha_h = 985845
alpha_h_box = 985871
alpha_h_box_outline = 986112
alpha_h_circle = 986113
alpha_h_circle_outline = 986114
alpha_i = 985846
alpha_i_box = 985872
alpha_i_box_outline = 986115
alpha_i_circle = 986116
alpha_i_circle_outline = 986117
alpha_j = 985847
alpha_j_box = 985873
alpha_j_box_outline = 986118
alpha_j_circle = 986119
alpha_j_circle_outline = 986120
alpha_k = 985848
alpha_k_box = 985874
alpha_k_box_outline = 986121
alpha_k_circle = 986122
alpha_k_circle_outline = 986123
alpha_l = 985849
alpha_l_box = 985875
alpha_l_box_outline = 986124
alpha_l_circle = 986125
alpha_l_circle_outline = 986126
alpha_m = 985850
alpha_m_box = 985876
alpha_m_box_outline = 986127
alpha_m_circle = 986128
alpha_m_circle_outline = 986129
alpha_n = 985851
alpha_n_box = 985877
alpha_n_box_outline = 986130
alpha_n_circle = 986131
alpha_n_circle_outline = 986132
alpha_o = 985852
alpha_o_box = 985878
alpha_o_box_outline = 986133
alpha_o_circle = 986134
alpha_o_circle_outline = 986135
alpha_p = 985853
alpha_p_box = 985879
alpha_p_box_outline = 986136
alpha_p_circle = 986137
alpha_p_circle_outline = 986138
alpha_q = 985854
alpha_q_box = 985880
alpha_q_box_outline = 986139
alpha_q_circle = 986140
alpha_q_circle_outline = 986141
alpha_r = 985855
alpha_r_box = 985881
alpha_r_box_outline = 986142
alpha_r_circle = 986143
alpha_r_circle_outline = 986144
alpha_s = 985856
alpha_s_box = 985882
alpha_s_box_outline = 986145
alpha_s_circle = 986146
alpha_s_circle_outline = 986147
alpha_t = 985857
alpha_t_box = 985883
alpha_t_box_outline = 986148
alpha_t_circle = 986149
alpha_t_circle_outline = 986150
alpha_u = 985858
alpha_u_box = 985884
alpha_u_box_outline = 986151
alpha_u_circle = 986152
alpha_u_circle_outline = 986153
alpha_v = 985859
alpha_v_box = 985885
alpha_v_box_outline = 986154
alpha_v_circle = 986155
alpha_v_circle_outline = 986156
alpha_w = 985860
alpha_w_box = 985886
alpha_w_box_outline = 986157
alpha_w_circle = 986158
alpha_w_circle_outline = 986159
alpha_x = 985861
alpha_x_box = 985887
alpha_x_box_outline = 986160
alpha_x_circle = 986161
alpha_x_circle_outline = 986162
alpha_y = 985862
alpha_y_box = 985888
alpha_y_box_outline = 986163
alpha_y_circle = 986164
alpha_y_circle_outline = 986165
alpha_z = 985863
alpha_z_box = 985889
alpha_z_box_outline = 986166
alpha_z_circle = 986167
alpha_z_circle_outline = 986168
alphabet_aurebesh = 987948
alphabet_cyrillic = 987949
alphabet_greek = 987950
alphabet_latin = 987951
alphabet_piqad = 987952
alphabet_tengwar = 987959
alphabetical = 983084
alphabetical_off = 987148
alphabetical_variant = 987149
alphabetical_variant_off = 987150
altimeter = 984535
ambulance = 983087
ammunition = 986344
ampersand = 985741
amplifier = 983088
amplifier_off = 987573
anchor = 983089
android = 983090
android_studio = 983092
angle_acute = 985399
angle_obtuse = 985400
angle_right = 985401
angular = 984754
angularjs = 984767
animation = 984536
animation_outline = 985743
animation_play = 985402
animation_play_outline = 985744
ansible = 987290
antenna = 987417
anvil = 985243
apache_kafka = 987151
api = 987291
api_off = 987735
apple = 983093
apple_finder = 983094
apple_icloud = 983096
apple_ios = 983095
apple_keyboard_caps = 984626
apple_keyboard_command = 984627
apple_keyboard_control = 984628
apple_keyboard_option = 984629
apple_keyboard_shift = 984630
apple_safari = 983097
application = 985286
application_array = 987381
application_array_outline = 987382
application_braces = 987383
application_braces_outline = 987384
application_brackets = 986251
application_brackets_outline = 986252
application_cog = 984693
application_cog_outline = 988535
application_edit = 983214
application_edit_outline = 984601
application_export = 986541
application_import = 986542
application_outline = 984596
application_parentheses = 987385
application_parentheses_outline = 987386
application_settings = 985952
application_settings_outline = 988501
application_variable = 987387
application_variable_outline = 987388
approximately_equal = 987038
approximately_equal_box = 987039
apps = 983099
apps_box = 986438
arch = 985287
archive = 983100
archive_alert = 988413
archive_alert_outline = 988414
archive_arrow_down = 987737
archive_arrow_down_outline = 987738
archive_arrow_up = 987739
archive_arrow_up_outline = 987740
archive_cancel = 989003
archive_cancel_outline = 989004
archive_check = 989005
archive_check_outline = 989006
archive_clock = 989007
archive_clock_outline = 989008
archive_cog = 989009
archive_cog_outline = 989010
archive_edit = 989011
archive_edit_outline = 989012
archive_eye = 989013
archive_eye_outline = 989014
archive_lock = 989015
archive_lock_open = 989016
archive_lock_open_outline = 989017
archive_lock_outline = 989018
archive_marker = 989019
archive_marker_outline = 989020
archive_minus = 989021
archive_minus_outline = 989022
archive_music = 989023
archive_music_outline = 989024
archive_off = 989025
archive_off_outline = 989026
archive_outline = 987662
archive_plus = 989027
archive_plus_outline = 989028
archive_refresh = 989029
archive_refresh_outline = 989030
archive_remove = 989031
archive_remove_outline = 989032
archive_search = 989033
archive_search_outline = 989034
archive_settings = 989035
archive_settings_outline = 989036
archive_star = 989037
archive_star_outline = 989038
archive_sync = 989039
archive_sync_outline = 989040
arm_flex = 987095
arm_flex_outline = 987094
arrange_bring_forward = 983101
arrange_bring_to_front = 983102
arrange_send_backward = 983103
arrange_send_to_back = 983104
arrow_all = 983105
arrow_bottom_left = 983106
arrow_bottom_left_bold_box = 989540
arrow_bottom_left_bold_box_outline = 989541
arrow_bottom_left_bold_outline = 985527
arrow_bottom_left_thick = 985528
arrow_bottom_left_thin = 989622
arrow_bottom_left_thin_circle_outline = 988566
arrow_bottom_right = 983107
arrow_bottom_right_bold_box = 989542
arrow_bottom_right_bold_box_outline = 989543
arrow_bottom_right_bold_outline = 985529
arrow_bottom_right_thick = 985530
arrow_bottom_right_thin = 989623
arrow_bottom_right_thin_circle_outline = 988565
arrow_collapse = 984597
arrow_collapse_all = 983108
arrow_collapse_down = 984978
arrow_collapse_horizontal = 985164
arrow_collapse_left = 984979
arrow_collapse_right = 984980
arrow_collapse_up = 984981
arrow_collapse_vertical = 985165
arrow_decision = 985531
arrow_decision_auto = 985532
arrow_decision_auto_outline = 985533
arrow_decision_outline = 985534
arrow_down = 983109
arrow_down_bold = 984878
arrow_down_bold_box = 984879
arrow_down_bold_box_outline = 984880
arrow_down_bold_circle = 983111
arrow_down_bold_circle_outline = 983112
arrow_down_bold_hexagon_outline = 983113
arrow_down_bold_outline = 985535
arrow_down_box = 984768
arrow_down_circle = 986331
arrow_down_circle_outline = 986332
arrow_down_drop_circle = 983114
arrow_down_drop_circle_outline = 983115
arrow_down_left = 989089
arrow_down_left_bold = 989090
arrow_down_right = 989091
arrow_down_right_bold = 989092
arrow_down_thick = 983110
arrow_down_thin = 989619
arrow_down_thin_circle_outline = 988569
arrow_expand = 984598
arrow_expand_all = 983116
arrow_expand_down = 984982
arrow_expand_horizontal = 985166
arrow_expand_left = 984983
arrow_expand_right = 984984
arrow_expand_up = 984985
arrow_expand_vertical = 985167
arrow_horizontal_lock = 987483
arrow_left = 983117
arrow_left_bold = 984881
arrow_left_bold_box = 984882
arrow_left_bold_box_outline = 984883
arrow_left_bold_circle = 983119
arrow_left_bold_circle_outline = 983120
arrow_left_bold_hexagon_outline = 983121
arrow_left_bold_outline = 985536
arrow_left_bottom = 989093
arrow_left_bottom_bold = 989094
arrow_left_box = 984769
arrow_left_circle = 986333
arrow_left_circle_outline = 986334
arrow_left_drop_circle = 983122
arrow_left_drop_circle_outline = 983123
arrow_left_right = 986739
arrow_left_right_bold = 986740
arrow_left_right_bold_outline = 985537
arrow_left_thick = 983118
arrow_left_thin = 989617
arrow_left_thin_circle_outline = 988570
arrow_left_top = 989095
arrow_left_top_bold = 989096
arrow_oscillating = 990353
arrow_oscillating_off = 990354
arrow_projectile = 989248
arrow_projectile_multiple = 989247
arrow_right = 983124
arrow_right_bold = 984884
arrow_right_bold_box = 984885
arrow_right_bold_box_outline = 984886
arrow_right_bold_circle = 983126
arrow_right_bold_circle_outline = 983127
arrow_right_bold_hexagon_outline = 983128
arrow_right_bold_outline = 985538
arrow_right_bottom = 989097
arrow_right_bottom_bold = 989098
arrow_right_box = 984770
arrow_right_circle = 986335
arrow_right_circle_outline = 986336
arrow_right_drop_circle = 983129
arrow_right_drop_circle_outline = 983130
arrow_right_thick = 983125
arrow_right_thin = 989616
arrow_right_thin_circle_outline = 988568
arrow_right_top = 989099
arrow_right_top_bold = 989100
arrow_split_horizontal = 985403
arrow_split_vertical = 985404
arrow_top_left = 983131
arrow_top_left_bold_box = 989544
arrow_top_left_bold_box_outline = 989545
arrow_top_left_bold_outline = 985539
arrow_top_left_bottom_right = 986741
arrow_top_left_bottom_right_bold = 986742
arrow_top_left_thick = 985540
arrow_top_left_thin = 989621
arrow_top_left_thin_circle_outline = 988563
arrow_top_right = 983132
arrow_top_right_bold_box = 989546
arrow_top_right_bold_box_outline = 989547
arrow_top_right_bold_outline = 985541
arrow_top_right_bottom_left = 986743
arrow_top_right_bottom_left_bold = 986744
arrow_top_right_thick = 985542
arrow_top_right_thin = 989620
arrow_top_right_thin_circle_outline = 988564
arrow_u_down_left = 989101
arrow_u_down_left_bold = 989102
arrow_u_down_right = 989103
arrow_u_down_right_bold = 989104
arrow_u_left_bottom = 989105
arrow_u_left_bottom_bold = 989106
arrow_u_left_top = 989107
arrow_u_left_top_bold = 989108
arrow_u_right_bottom = 989109
arrow_u_right_bottom_bold = 989110
arrow_u_right_top = 989111
arrow_u_right_top_bold = 989112
arrow_u_up_left = 989113
arrow_u_up_left_bold = 989114
arrow_u_up_right = 989115
arrow_u_up_right_bold = 989116
arrow_up = 983133
arrow_up_bold = 984887
arrow_up_bold_box = 984888
arrow_up_bold_box_outline = 984889
arrow_up_bold_circle = 983135
arrow_up_bold_circle_outline = 983136
arrow_up_bold_hexagon_outline = 983137
arrow_up_bold_outline = 985543
arrow_up_box = 984771
arrow_up_circle = 986337
arrow_up_circle_outline = 986338
arrow_up_down = 986745
arrow_up_down_bold = 986746
arrow_up_down_bold_outline = 985544
arrow_up_drop_circle = 983138
arrow_up_drop_circle_outline = 983139
arrow_up_left = 989117
arrow_up_left_bold = 989118
arrow_up_right = 989119
arrow_up_right_bold = 989120
arrow_up_thick = 983134
arrow_up_thin = 989618
arrow_up_thin_circle_outline = 988567
arrow_vertical_lock = 987484
artboard = 990106
artstation = 985947
aspect_ratio = 985636
assistant = 983140
asterisk = 984772
asterisk_circle_outline = 989735
at = 983141
atlassian = 985092
atm = 986439
atom = 984936
atom_variant = 986747
attachment = 983142
attachment_check = 989889
attachment_lock = 989636
attachment_minus = 989890
attachment_off = 989891
attachment_plus = 989892
attachment_remove = 989893
atv = 990064
audio_input_rca = 989291
audio_input_stereo_minijack = 989292
audio_input_xlr = 989293
audio_video = 985405
audio_video_off = 987574
augmented_reality = 985168
aurora = 990137
auto_download = 988030
auto_fix = 983144
auto_mode = 990240
auto_upload = 983145
autorenew = 983146
autorenew_off = 989671
av_timer = 983147
awning = 990087
awning_outline = 990088
aws = 986639
axe = 985288
axe_battle = 989250
axis = 986440
axis_arrow = 986441
axis_arrow_info = 988174
axis_arrow_lock = 986442
axis_lock = 986443
axis_x_arrow = 986444
axis_x_arrow_lock = 986445
axis_x_rotate_clockwise = 986446
axis_x_rotate_counterclockwise = 986447
axis_x_y_arrow_lock = 986448
axis_y_arrow = 986449
axis_y_arrow_lock = 986450
axis_y_rotate_clockwise = 986451
axis_y_rotate_counterclockwise = 986452
axis_z_arrow = 986453
axis_z_arrow_lock = 986454
axis_z_rotate_clockwise = 986455
axis_z_rotate_counterclockwise = 986456
babel = 985637
baby = 983148
baby_bottle = 986937
baby_bottle_outline = 986938
baby_buggy = 988128
baby_buggy_off = 989939
baby_carriage = 984719
baby_carriage_off = 987040
baby_face = 986748
baby_face_outline = 986749
backburger = 983149
backspace = 983150
backspace_outline = 985948
backspace_reverse = 986750
backspace_reverse_outline = 986751
backup_restore = 983151
bacteria = 986837
bacteria_outline = 986838
badge_account = 986535
badge_account_alert = 986536
badge_account_alert_outline = 986537
badge_account_horizontal = 986637
badge_account_horizontal_outline = 986638
badge_account_outline = 986538
badminton = 985169
bag_carry_on = 986939
bag_carry_on_check = 986469
bag_carry_on_off = 986940
bag_checked = 986941
bag_personal = 986640
bag_personal_off = 986641
bag_personal_off_outline = 986642
bag_personal_outline = 986643
bag_personal_plus = 990372
bag_personal_plus_outline = 990373
bag_personal_tag = 989964
bag_personal_tag_outline = 989965
bag_suitcase = 988555
bag_suitcase_off = 988557
bag_suitcase_off_outline = 988558
bag_suitcase_outline = 988556
baguette = 986942
balcony = 989207
balloon = 985638
ballot = 985545
ballot_outline = 985546
ballot_recount = 986169
ballot_recount_outline = 986170
bandage = 986543
bank = 983152
bank_check = 988757
bank_circle = 990211
bank_circle_outline = 990212
bank_minus = 986544
bank_off = 988758
bank_off_outline = 988759
bank_outline = 986752
bank_plus = 986545
bank_remove = 986546
bank_transfer = 985639
bank_transfer_in = 985640
bank_transfer_out = 985641
barcode = 983153
barcode_off = 987702
barcode_scan = 983154
barley = 983155
barley_off = 985949
barn = 985950
barrel = 983156
barrel_outline = 989736
baseball = 985170
baseball_bat = 985171
baseball_diamond = 988652
baseball_diamond_outline = 988653
baseball_outline = 990298
bash = 987523
basket = 983158
basket_check = 989413
basket_check_outline = 989414
basket_fill = 983159
basket_minus = 988451
basket_minus_outline = 988452
basket_off = 988453
basket_off_outline = 988454
basket_outline = 987521
basket_plus = 988455
basket_plus_outline = 988456
basket_remove = 988457
basket_remove_outline = 988458
basket_unfill = 983160
basketball = 985094
basketball_hoop = 986171
basketball_hoop_outline = 986172
bat = 985951
bathtub = 989208
bathtub_outline = 989209
battery = 983161
battery_10 = 983162
battery_10_bluetooth = 985406
battery_20 = 983163
battery_20_bluetooth = 985407
battery_30 = 983164
battery_30_bluetooth = 985408
battery_40 = 983165
battery_40_bluetooth = 985409
battery_50 = 983166
battery_50_bluetooth = 985410
battery_60 = 983167
battery_60_bluetooth = 985411
battery_70 = 983168
battery_70_bluetooth = 985412
battery_80 = 983169
battery_80_bluetooth = 985413
battery_90 = 983170
battery_90_bluetooth = 985414
battery_alert = 983171
battery_alert_bluetooth = 985415
battery_alert_variant = 987340
battery_alert_variant_outline = 987341
battery_arrow_down = 989150
battery_arrow_down_outline = 989151
battery_arrow_up = 989152
battery_arrow_up_outline = 989153
battery_bluetooth = 985416
battery_bluetooth_variant = 985417
battery_charging = 983172
battery_charging_10 = 985244
battery_charging_100 = 983173
battery_charging_20 = 983174
battery_charging_30 = 983175
battery_charging_40 = 983176
battery_charging_50 = 985245
battery_charging_60 = 983177
battery_charging_70 = 985246
battery_charging_80 = 983178
battery_charging_90 = 983179
battery_charging_high = 987814
battery_charging_low = 987812
battery_charging_medium = 987813
battery_charging_outline = 985247
battery_charging_wireless = 985095
battery_charging_wireless_10 = 985096
battery_charging_wireless_20 = 985097
battery_charging_wireless_30 = 985098
battery_charging_wireless_40 = 985099
battery_charging_wireless_50 = 985100
battery_charging_wireless_60 = 985101
battery_charging_wireless_70 = 985102
battery_charging_wireless_80 = 985103
battery_charging_wireless_90 = 985104
battery_charging_wireless_alert = 985105
battery_charging_wireless_outline = 985106
battery_check = 989154
battery_check_outline = 989155
battery_clock = 989669
battery_clock_outline = 989670
battery_heart = 987663
battery_heart_outline = 987664
battery_heart_variant = 987665
battery_high = 987811
battery_lock = 989084
battery_lock_open = 989085
battery_low = 987809
battery_medium = 987810
battery_minus = 989156
battery_minus_outline = 989157
battery_minus_variant = 983180
battery_negative = 983181
battery_off = 987741
battery_off_outline = 987742
battery_outline = 983182
battery_plus = 989158
battery_plus_outline = 989159
battery_plus_variant = 983183
battery_positive = 983184
battery_remove = 989160
battery_remove_outline = 989161
battery_sync = 989236
battery_sync_outline = 989237
battery_unknown = 983185
battery_unknown_bluetooth = 985418
beach = 983186
beaker = 986346
beaker_alert = 987689
beaker_alert_outline = 987690
beaker_check = 987691
beaker_check_outline = 987692
beaker_minus = 987693
beaker_minus_outline = 987694
beaker_outline = 984720
beaker_plus = 987695
beaker_plus_outline = 987696
beaker_question = 987697
beaker_question_outline = 987698
beaker_remove = 987699
beaker_remove_outline = 987700
bed = 983779
bed_clock = 990100
bed_double = 987092
bed_double_outline = 987091
bed_empty = 985248
bed_king = 987090
bed_king_outline = 987089
bed_outline = 983193
bed_queen = 987088
bed_queen_outline = 987099
bed_single = 987245
bed_single_outline = 987246
bee = 987041
bee_flower = 987042
beehive_off_outline = 988141
beehive_outline = 987342
beekeeper = 988386
beer = 983192
beer_outline = 987916
bell = 983194
bell_alert = 986457
bell_alert_outline = 986753
bell_badge = 987499
bell_badge_outline = 983416
bell_cancel = 988135
bell_cancel_outline = 988136
bell_check = 987621
bell_check_outline = 987622
bell_circle = 986458
bell_circle_outline = 986459
bell_cog = 989737
bell_cog_outline = 989738
bell_minus = 988137
bell_minus_outline = 988138
bell_off = 983195
bell_off_outline = 985745
bell_outline = 983196
bell_plus = 983197
bell_plus_outline = 985746
bell_remove = 988139
bell_remove_outline = 988140
bell_ring = 983198
bell_ring_outline = 983199
bell_sleep = 983200
bell_sleep_outline = 985747
bench = 990241
bench_back = 990242
beta = 983201
betamax = 985547
biathlon = 986644
bicycle = 987292
bicycle_basket = 987701
bicycle_cargo = 989340
bicycle_electric = 988596
bicycle_penny_farthing = 988649
bike = 983203
bike_fast = 987423
bike_pedal = 990243
bike_pedal_clipless = 990244
bike_pedal_mountain = 990245
billboard = 987152
billiards = 985953
billiards_rack = 985954
binoculars = 983205
bio = 983206
biohazard = 983207
bird = 988614
bitbucket = 983208
bitcoin = 985107
black_mesa = 983209
blender = 986347
blender_outline = 989210
blender_software = 983211
blinds = 983212
blinds_horizontal = 989739
blinds_horizontal_closed = 989740
blinds_open = 987153
blinds_vertical = 989741
blinds_vertical_closed = 989742
block_helper = 983213
blood_bag = 986348
bluetooth = 983215
bluetooth_audio = 983216
bluetooth_connect = 983217
bluetooth_off = 983218
bluetooth_settings = 983219
bluetooth_transfer = 983220
blur = 983221
blur_linear = 983222
blur_off = 983223
blur_radial = 983224
bolt = 986547
bomb = 984721
bomb_off = 984773
bone = 983225
bone_off = 989664
book = 983226
book_account = 988077
book_account_outline = 988078
book_alert = 988796
book_alert_outline = 988797
book_alphabet = 984605
book_arrow_down = 988798
book_arrow_down_outline = 988799
book_arrow_left = 988800
book_arrow_left_outline = 988801
book_arrow_right = 988802
book_arrow_right_outline = 988803
book_arrow_up = 988804
book_arrow_up_outline = 988805
book_cancel = 988806
book_cancel_outline = 988807
book_check = 988403
book_check_outline = 988404
book_clock = 988808
book_clock_outline = 988809
book_cog = 988810
book_cog_outline = 988811
book_cross = 983202
book_edit = 988812
book_edit_outline = 988813
book_education = 988873
book_education_outline = 988874
book_heart = 989725
book_heart_outline = 989726
book_information_variant = 987247
book_lock = 984986
book_lock_open = 984987
book_lock_open_outline = 988814
book_lock_outline = 988815
book_marker = 988816
book_marker_outline = 988817
book_minus = 984537
book_minus_multiple = 985748
book_minus_multiple_outline = 985355
book_minus_outline = 988818
book_multiple = 983227
book_multiple_outline = 984118
book_music = 983143
book_music_outline = 988819
book_off = 988820
book_off_outline = 988821
book_open = 983229
book_open_blank_variant = 983230
book_open_outline = 985955
book_open_page_variant = 984538
book_open_page_variant_outline = 988630
book_open_variant = 988407
book_outline = 985956
book_play = 986754
book_play_outline = 986755
book_plus = 984539
book_plus_multiple = 985749
book_plus_multiple_outline = 985822
book_plus_outline = 988822
book_refresh = 988823
book_refresh_outline = 988824
book_remove = 985751
book_remove_multiple = 985750
book_remove_multiple_outline = 984266
book_remove_outline = 988825
book_search = 986756
book_search_outline = 986757
book_settings = 988826
book_settings_outline = 988827
book_sync = 988828
book_sync_outline = 988872
book_variant = 983231
bookmark = 983232
bookmark_box = 990069
bookmark_box_multiple = 989548
bookmark_box_multiple_outline = 989549
bookmark_box_outline = 990070
bookmark_check = 983233
bookmark_check_outline = 988027
bookmark_minus = 985548
bookmark_minus_outline = 985549
bookmark_multiple = 986645
bookmark_multiple_outline = 986646
bookmark_music = 983234
bookmark_music_outline = 988025
bookmark_off = 985550
bookmark_off_outline = 985551
bookmark_outline = 983235
bookmark_plus = 983237
bookmark_plus_outline = 983236
bookmark_remove = 983238
bookmark_remove_outline = 988026
bookshelf = 987743
boom_gate = 986758
boom_gate_alert = 986759
boom_gate_alert_outline = 986760
boom_gate_arrow_down = 986761
boom_gate_arrow_down_outline = 986762
boom_gate_arrow_up = 986764
boom_gate_arrow_up_outline = 986765
boom_gate_outline = 986763
boom_gate_up = 989177
boom_gate_up_outline = 989178
boombox = 984540
boomerang = 987343
bootstrap = 984774
border_all = 983239
border_all_variant = 985249
border_bottom = 983240
border_bottom_variant = 985250
border_color = 983241
border_horizontal = 983242
border_inside = 983243
border_left = 983244
border_left_variant = 985251
border_none = 983245
border_none_variant = 985252
border_outside = 983246
border_radius = 989940
border_right = 983247
border_right_variant = 985253
border_style = 983248
border_top = 983249
border_top_variant = 985254
border_vertical = 983250
bottle_soda = 987248
bottle_soda_classic = 987249
bottle_soda_classic_outline = 988003
bottle_soda_outline = 987250
bottle_tonic = 987438
bottle_tonic_outline = 987439
bottle_tonic_plus = 987440
bottle_tonic_plus_outline = 987441
bottle_tonic_skull = 987442
bottle_tonic_skull_outline = 987443
bottle_wine = 985172
bottle_wine_outline = 987920
bow_arrow = 989249
bow_tie = 984696
bowl = 983694
bowl_mix = 984599
bowl_mix_outline = 983780
bowl_outline = 983721
bowling = 983251
box = 983252
box_cutter = 983253
box_cutter_off = 985930
box_shadow = 984631
boxing_glove = 985957
braille = 985552
brain = 985553
bread_slice = 986350
bread_slice_outline = 986351
bridge = 984600
briefcase = 983254
briefcase_account = 986352
briefcase_account_outline = 986353
briefcase_arrow_left_right = 989837
briefcase_arrow_left_right_outline = 989838
briefcase_arrow_up_down = 989839
briefcase_arrow_up_down_outline = 989840
briefcase_check = 983255
briefcase_check_outline = 987934
briefcase_clock = 987344
briefcase_clock_outline = 987345
briefcase_download = 983256
briefcase_download_outline = 986173
briefcase_edit = 985752
briefcase_edit_outline = 986174
briefcase_eye = 989145
briefcase_eye_outline = 989146
briefcase_minus = 985642
briefcase_minus_outline = 986175
briefcase_off = 988760
briefcase_off_outline = 988761
briefcase_outline = 985108
briefcase_plus = 985643
briefcase_plus_outline = 986176
briefcase_remove = 985644
briefcase_remove_outline = 986177
briefcase_search = 985645
briefcase_search_outline = 986178
briefcase_upload = 983257
briefcase_upload_outline = 986179
briefcase_variant = 988308
briefcase_variant_off = 988762
briefcase_variant_off_outline = 988763
briefcase_variant_outline = 988309
brightness_1 = 983258
brightness_2 = 983259
brightness_3 = 983260
brightness_4 = 983261
brightness_5 = 983262
brightness_6 = 983263
brightness_7 = 983264
brightness_auto = 983265
brightness_percent = 986354
broadcast = 988960
broadcast_off = 988961
broom = 983266
brush = 983267
brush_off = 989041
brush_outline = 989709
brush_variant = 989203
bucket = 988181
bucket_outline = 988182
buffet = 984440
bug = 983268
bug_check = 985646
bug_check_outline = 985647
bug_outline = 985648
bug_pause = 989941
bug_pause_outline = 989942
bug_play = 989943
bug_play_outline = 989944
bug_stop = 989945
bug_stop_outline = 989946
bugle = 986548
bulkhead_light = 989743
bulldozer = 985890
bullet = 986355
bulletin_board = 983269
bullhorn = 983270
bullhorn_outline = 985891
bullhorn_variant = 989550
bullhorn_variant_outline = 989551
bullseye = 984541
bullseye_arrow = 985289
bulma = 987879
bunk_bed = 987906
bunk_bed_outline = 983191
bus = 983271
bus_alert = 985753
bus_articulated_end = 984988
bus_articulated_front = 984989
bus_clock = 985290
bus_double_decker = 984990
bus_electric = 989469
bus_marker = 987666
bus_multiple = 986943
bus_school = 984991
bus_side = 984992
bus_sign = 990401
bus_stop = 987154
bus_stop_covered = 987155
bus_stop_uncovered = 987156
bus_wrench = 990402
butterfly = 988553
butterfly_outline = 988554
button_cursor = 990031
button_pointer = 990032
cabin_a_frame = 989324
cable_data = 988052
cached = 983272
cactus = 986549
cake = 983273
cake_layered = 983274
cake_variant = 983275
cake_variant_outline = 989168
calculator = 983276
calculator_variant = 985754
calculator_variant_outline = 988582
calendar = 983277
calendar_account = 986839
calendar_account_outline = 986840
calendar_alert = 985649
calendar_alert_outline = 990050
calendar_arrow_left = 987444
calendar_arrow_right = 987445
calendar_badge = 990109
calendar_badge_outline = 990110
calendar_blank = 983278
calendar_blank_multiple = 987251
calendar_blank_outline = 985958
calendar_check = 983279
calendar_check_outline = 986180
calendar_clock = 983280
calendar_clock_outline = 988897
calendar_collapse_horizontal = 989341
calendar_collapse_horizontal_outline = 990051
calendar_cursor = 988539
calendar_cursor_outline = 990052
calendar_edit = 985255
calendar_edit_outline = 990053
calendar_end = 988780
calendar_end_outline = 990054
calendar_expand_horizontal = 989342
calendar_expand_horizontal_outline = 990055
calendar_export = 985892
calendar_export_outline = 990056
calendar_filter = 989746
calendar_filter_outline = 989747
calendar_heart = 985554
calendar_heart_outline = 990057
calendar_import = 985893
calendar_import_outline = 990058
calendar_lock = 988737
calendar_lock_open = 990043
calendar_lock_open_outline = 990044
calendar_lock_outline = 988738
calendar_minus = 986460
calendar_minus_outline = 990059
calendar_month = 986647
calendar_month_outline = 986648
calendar_multiple = 983281
calendar_multiple_check = 983282
calendar_multiselect = 985650
calendar_multiselect_outline = 990037
calendar_outline = 985959
calendar_plus = 983283
calendar_plus_outline = 990060
calendar_question = 984722
calendar_question_outline = 990061
calendar_range = 984697
calendar_range_outline = 985960
calendar_refresh = 983521
calendar_refresh_outline = 983555
calendar_remove = 983284
calendar_remove_outline = 986181
calendar_search = 985420
calendar_search_outline = 990062
calendar_star = 985555
calendar_star_four_points = 990239
calendar_star_outline = 990035
calendar_start = 988781
calendar_start_outline = 990063
calendar_sync = 986766
calendar_sync_outline = 986767
calendar_text = 983285
calendar_text_outline = 986182
calendar_today = 983286
calendar_today_outline = 989744
calendar_week = 985651
calendar_week_begin = 985652
calendar_week_begin_outline = 989745
calendar_week_outline = 989748
calendar_weekend = 986841
calendar_weekend_outline = 986842
call_made = 983287
call_merge = 983288
call_missed = 983289
call_received = 983290
call_split = 983291
camcorder = 983292
camcorder_off = 983295
camera = 983296
camera_account = 985291
camera_burst = 984723
camera_control = 985961
camera_document = 989297
camera_document_off = 989298
camera_enhance = 983297
camera_enhance_outline = 985962
camera_flip = 988633
camera_flip_outline = 988634
camera_front = 983298
camera_front_variant = 983299
camera_gopro = 984993
camera_image = 985292
camera_iris = 983300
camera_lock = 989716
camera_lock_open = 990221
camera_lock_open_outline = 990222
camera_lock_outline = 989717
camera_marker = 989607
camera_marker_outline = 989608
camera_metering_center = 984994
camera_metering_matrix = 984995
camera_metering_partial = 984996
camera_metering_spot = 984997
camera_off = 984543
camera_off_outline = 989631
camera_outline = 986461
camera_party_mode = 983301
camera_plus = 986843
camera_plus_outline = 986844
camera_rear = 983302
camera_rear_variant = 983303
camera_retake = 986649
camera_retake_outline = 986650
camera_switch = 983304
camera_switch_outline = 985162
camera_timer = 983305
camera_wireless = 986550
camera_wireless_outline = 986551
campfire = 986845
cancel = 984890
candelabra = 989138
candelabra_fire = 989139
candle = 984546
candy = 989552
candy_off = 989553
candy_off_outline = 989554
candy_outline = 989555
candycane = 983306
cannabis = 984998
cannabis_off = 988782
caps_lock = 985755
car = 983307
car_2_plus = 987157
car_3_plus = 987158
car_arrow_left = 988082
car_arrow_right = 988083
car_back = 986651
car_battery = 983308
car_brake_abs = 986183
car_brake_alert = 986184
car_brake_fluid_level = 989449
car_brake_hold = 986462
car_brake_low_pressure = 989450
car_brake_parking = 986463
car_brake_retarder = 987159
car_brake_temperature = 989451
car_brake_worn_linings = 989452
car_child_seat = 987043
car_clock = 989556
car_clutch = 987160
car_cog = 988108
car_connected = 983309
car_convertible = 984999
car_coolant_level = 987161
car_cruise_control = 986464
car_defrost_front = 986465
car_defrost_rear = 986466
car_door = 985963
car_door_lock = 987293
car_door_lock_open = 990337
car_electric = 985964
car_electric_outline = 988597
car_emergency = 988687
car_esp = 986185
car_estate = 985000
car_hatchback = 985001
car_info = 987582
car_key = 985965
car_lifted_pickup = 988461
car_light_alert = 989453
car_light_dimmed = 986186
car_light_fog = 986187
car_light_high = 986188
car_limousine = 985293
car_multiple = 985966
car_off = 986652
car_outline = 988397
car_parking_lights = 986467
car_pickup = 985002
car_search = 990093
car_search_outline = 990094
car_seat = 987044
car_seat_cooler = 987045
car_seat_heater = 987046
car_select = 989305
car_settings = 988109
car_shift_pattern = 986944
car_side = 985003
car_speed_limiter = 989454
car_sports = 985004
car_tire_alert = 986189
car_traction_control = 986468
car_turbocharger = 987162
car_wash = 983310
car_windshield = 987163
car_windshield_outline = 987164
car_wireless = 989304
car_wrench = 989204
carabiner = 988352
caravan = 985005
card = 985967
card_account_details = 984530
card_account_details_outline = 986539
card_account_details_star = 983715
card_account_details_star_outline = 984795
card_account_mail = 983438
card_account_mail_outline = 986776
card_account_phone = 986777
card_account_phone_outline = 986778
card_bulleted = 985968
card_bulleted_off = 985969
card_bulleted_off_outline = 985970
card_bulleted_outline = 985971
card_bulleted_settings = 985972
card_bulleted_settings_outline = 985973
card_minus = 988672
card_minus_outline = 988673
card_multiple = 989169
card_multiple_outline = 989170
card_off = 988674
card_off_outline = 988675
card_outline = 985974
card_plus = 987647
card_plus_outline = 987648
card_remove = 988676
card_remove_outline = 988677
card_search = 987252
card_search_outline = 987253
card_text = 985975
card_text_outline = 985976
cards = 984632
cards_club = 985294
cards_club_outline = 989343
cards_diamond = 985295
cards_diamond_outline = 987165
cards_heart = 985296
cards_heart_outline = 989344
cards_outline = 984633
cards_playing = 989345
cards_playing_club = 989346
cards_playing_club_multiple = 989347
cards_playing_club_multiple_outline = 989348
cards_playing_club_outline = 989349
cards_playing_diamond = 989350
cards_playing_diamond_multiple = 989351
cards_playing_diamond_multiple_outline = 989352
cards_playing_diamond_outline = 989353
cards_playing_heart = 989354
cards_playing_heart_multiple = 989355
cards_playing_heart_multiple_outline = 989356
cards_playing_heart_outline = 989357
cards_playing_outline = 984634
cards_playing_spade = 989358
cards_playing_spade_multiple = 989359
cards_playing_spade_multiple_outline = 989360
cards_playing_spade_outline = 989361
cards_spade = 985297
cards_spade_outline = 989362
cards_variant = 984775
carrot = 983311
cart = 983312
cart_arrow_down = 986470
cart_arrow_right = 986190
cart_arrow_up = 986471
cart_check = 988650
cart_heart = 989408
cart_minus = 986472
cart_off = 984683
cart_outline = 983313
cart_percent = 990126
cart_plus = 983314
cart_remove = 986473
cart_variant = 988651
case_sensitive_alt = 983315
cash = 983316
cash_100 = 983317
cash_check = 988398
cash_clock = 989841
cash_edit = 990379
cash_fast = 989276
cash_lock = 988394
cash_lock_open = 988395
cash_marker = 986552
cash_minus = 987744
cash_multiple = 983318
cash_off = 990329
cash_plus = 987745
cash_refund = 985756
cash_register = 986356
cash_remove = 987746
cash_sync = 989842
cassette = 985556
cast = 983320
cast_audio = 987166
cast_audio_variant = 989001
cast_connected = 983321
cast_education = 986653
cast_off = 984970
cast_variant = 983071
castle = 983322
cat = 983323
cctv = 985006
cctv_off = 989279
ceiling_fan = 989079
ceiling_fan_light = 989080
ceiling_light = 984937
ceiling_light_multiple = 989405
ceiling_light_multiple_outline = 989406
ceiling_light_outline = 989127
cellphone = 983324
cellphone_arrow_down = 985557
cellphone_arrow_down_variant = 989637
cellphone_basic = 983326
cellphone_charging = 988055
cellphone_check = 989181
cellphone_cog = 985425
cellphone_dock = 983327
cellphone_information = 986945
cellphone_key = 985422
cellphone_link = 983329
cellphone_link_off = 983330
cellphone_lock = 985423
cellphone_marker = 989242
cellphone_message = 985299
cellphone_message_off = 987346
cellphone_nfc = 986768
cellphone_nfc_off = 987864
cellphone_off = 985424
cellphone_play = 987167
cellphone_remove = 985421
cellphone_screenshot = 985653
cellphone_settings = 983331
cellphone_sound = 985426
cellphone_text = 985298
cellphone_wireless = 985109
centos = 987418
certificate = 983332
certificate_outline = 987528
chair_rolling = 986952
chair_school = 983333
chandelier = 989075
charity = 986191
charity_search = 990338
chart_arc = 983334
chart_areaspline = 983335
chart_areaspline_variant = 986769
chart_bar = 983336
chart_bar_stacked = 984938
chart_bell_curve = 986192
chart_bell_curve_cumulative = 987047
chart_box = 988493
chart_box_outline = 988494
chart_box_plus_outline = 988495
chart_bubble = 984547
chart_donut = 985007
chart_donut_variant = 985008
chart_gantt = 984684
chart_histogram = 983337
chart_line = 983338
chart_line_stacked = 984939
chart_line_variant = 985009
chart_multiline = 985300
chart_multiple = 987667
chart_pie = 983339
chart_pie_outline = 990175
chart_ppf = 988032
chart_sankey = 987615
chart_sankey_variant = 987616
chart_scatter_plot = 986770
chart_scatter_plot_hexbin = 984685
chart_timeline = 984686
chart_timeline_variant = 986771
chart_timeline_variant_shimmer = 988598
chart_tree = 986772
chart_waterfall = 989464
chat = 985977
chat_alert = 985978
chat_alert_outline = 987849
chat_minus = 988176
chat_minus_outline = 988179
chat_outline = 986846
chat_plus = 988175
chat_plus_outline = 988178
chat_processing = 985979
chat_processing_outline = 987850
chat_question = 988984
chat_question_outline = 988985
chat_remove = 988177
chat_remove_outline = 988180
chat_sleep = 987857
chat_sleep_outline = 987858
check = 983340
check_all = 983341
check_bold = 986654
check_circle = 984544
check_circle_outline = 984545
check_decagram = 984977
check_decagram_outline = 988992
check_network = 986195
check_network_outline = 986196
check_outline = 985173
check_underline = 986655
check_underline_circle = 986656
check_underline_circle_outline = 986657
checkbook = 985757
checkbook_arrow_left = 990237
checkbook_arrow_right = 990238
checkbox_blank = 983342
checkbox_blank_badge = 987510
checkbox_blank_badge_outline = 983319
checkbox_blank_circle = 983343
checkbox_blank_circle_outline = 983344
checkbox_blank_off = 987884
checkbox_blank_off_outline = 987885
checkbox_blank_outline = 983345
checkbox_intermediate = 985174
checkbox_intermediate_variant = 990036
checkbox_marked = 983346
checkbox_marked_circle = 983347
checkbox_marked_circle_auto_outline = 990246
checkbox_marked_circle_minus_outline = 990247
checkbox_marked_circle_outline = 983348
checkbox_marked_circle_plus_outline = 989479
checkbox_marked_outline = 983349
checkbox_multiple_blank = 983350
checkbox_multiple_blank_circle = 984635
checkbox_multiple_blank_circle_outline = 984636
checkbox_multiple_blank_outline = 983351
checkbox_multiple_marked = 983352
checkbox_multiple_marked_circle = 984637
checkbox_multiple_marked_circle_outline = 984638
checkbox_multiple_marked_outline = 983353
checkbox_multiple_outline = 986193
checkbox_outline = 986194
checkerboard = 983354
checkerboard_minus = 987650
checkerboard_plus = 987649
checkerboard_remove = 987651
cheese = 987833
cheese_off = 988142
chef_hat = 985980
chemical_weapon = 983355
chess_bishop = 985180
chess_king = 985175
chess_knight = 985176
chess_pawn = 985177
chess_queen = 985178
chess_rook = 985179
chevron_double_down = 983356
chevron_double_left = 983357
chevron_double_right = 983358
chevron_double_up = 983359
chevron_down = 983360
chevron_down_box = 985558
chevron_down_box_outline = 985559
chevron_down_circle = 985894
chevron_down_circle_outline = 985895
chevron_left = 983361
chevron_left_box = 985560
chevron_left_box_outline = 985561
chevron_left_circle = 985896
chevron_left_circle_outline = 985897
chevron_right = 983362
chevron_right_box = 985562
chevron_right_box_outline = 985563
chevron_right_circle = 985898
chevron_right_circle_outline = 985899
chevron_triple_down = 986553
chevron_triple_left = 986554
chevron_triple_right = 986555
chevron_triple_up = 986556
chevron_up = 983363
chevron_up_box = 985564
chevron_up_box_outline = 985565
chevron_up_circle = 985900
chevron_up_circle_outline = 985901
chili_alert = 989162
chili_alert_outline = 989163
chili_hot = 985010
chili_hot_outline = 989164
chili_medium = 985011
chili_medium_outline = 989165
chili_mild = 985012
chili_mild_outline = 989166
chili_off = 988263
chili_off_outline = 989167
chip = 984602
church = 983364
church_outline = 989954
cigar = 987529
cigar_off = 988187
circle = 984933
circle_box = 988636
circle_box_outline = 988637
circle_double = 986773
circle_edit_outline = 985301
circle_expand = 986774
circle_half = 988053
circle_half_full = 988054
circle_medium = 985566
circle_multiple = 985912
circle_multiple_outline = 984725
circle_off_outline = 987347
circle_opacity = 989267
circle_outline = 984934
circle_slice_1 = 985758
circle_slice_2 = 985759
circle_slice_3 = 985760
circle_slice_4 = 985761
circle_slice_5 = 985762
circle_slice_6 = 985763
circle_slice_7 = 985764
circle_slice_8 = 985765
circle_small = 985567
circular_saw = 986658
city = 983366
city_switch = 990248
city_variant = 985654
city_variant_outline = 985655
clipboard = 983367
clipboard_account = 983368
clipboard_account_outline = 986197
clipboard_alert = 983369
clipboard_alert_outline = 986359
clipboard_arrow_down = 983370
clipboard_arrow_down_outline = 986198
clipboard_arrow_left = 983371
clipboard_arrow_left_outline = 986360
clipboard_arrow_right = 986361
clipboard_arrow_right_outline = 986362
clipboard_arrow_up = 986199
clipboard_arrow_up_outline = 986200
clipboard_check = 983374
clipboard_check_multiple = 987747
clipboard_check_multiple_outline = 987748
clipboard_check_outline = 985256
clipboard_clock = 988898
clipboard_clock_outline = 988899
clipboard_edit = 988389
clipboard_edit_outline = 988390
clipboard_file = 987749
clipboard_file_outline = 987750
clipboard_flow = 984776
clipboard_flow_outline = 987415
clipboard_list = 987348
clipboard_list_outline = 987349
clipboard_minus = 988696
clipboard_minus_outline = 988697
clipboard_multiple = 987751
clipboard_multiple_outline = 987752
clipboard_off = 988698
clipboard_off_outline = 988699
clipboard_outline = 983372
clipboard_play = 986201
clipboard_play_multiple = 987753
clipboard_play_multiple_outline = 987754
clipboard_play_outline = 986202
clipboard_plus = 984913
clipboard_plus_outline = 987935
clipboard_pulse = 985181
clipboard_pulse_outline = 985182
clipboard_remove = 988700
clipboard_remove_outline = 988701
clipboard_search = 988702
clipboard_search_outline = 988703
clipboard_text = 983373
clipboard_text_clock = 989433
clipboard_text_clock_outline = 989434
clipboard_text_multiple = 987755
clipboard_text_multiple_outline = 987756
clipboard_text_off = 988704
clipboard_text_off_outline = 988705
clipboard_text_outline = 985656
clipboard_text_play = 986203
clipboard_text_play_outline = 986204
clipboard_text_search = 988706
clipboard_text_search_outline = 988707
clippy = 983375
clock = 985428
clock_alert = 985429
clock_alert_outline = 984526
clock_check = 987048
clock_check_outline = 987049
clock_digital = 986775
clock_edit = 989626
clock_edit_outline = 989627
clock_end = 983377
clock_fast = 983378
clock_in = 983379
clock_minus = 989283
clock_minus_outline = 989284
clock_out = 983380
clock_outline = 983376
clock_plus = 989281
clock_plus_outline = 989282
clock_remove = 989285
clock_remove_outline = 989286
clock_star_four_points = 990249
clock_star_four_points_outline = 990250
clock_start = 983381
clock_time_eight = 988230
clock_time_eight_outline = 988242
clock_time_eleven = 988233
clock_time_eleven_outline = 988245
clock_time_five = 988227
clock_time_five_outline = 988239
clock_time_four = 988226
clock_time_four_outline = 988238
clock_time_nine = 988231
clock_time_nine_outline = 988243
clock_time_one = 988223
clock_time_one_outline = 988235
clock_time_seven = 988229
clock_time_seven_outline = 988241
clock_time_six = 988228
clock_time_six_outline = 988240
clock_time_ten = 988232
clock_time_ten_outline = 988244
clock_time_three = 988225
clock_time_three_outline = 988237
clock_time_twelve = 988234
clock_time_twelve_outline = 988246
clock_time_two = 988224
clock_time_two_outline = 988236
close = 983382
close_box = 983383
close_box_multiple = 986205
close_box_multiple_outline = 986206
close_box_outline = 983384
close_circle = 983385
close_circle_multiple = 984618
close_circle_multiple_outline = 985219
close_circle_outline = 983386
close_network = 983387
close_network_outline = 986207
close_octagon = 983388
close_octagon_outline = 983389
close_outline = 984777
close_thick = 988056
closed_caption = 983390
closed_caption_outline = 986557
cloud = 983391
cloud_alert = 985568
cloud_alert_outline = 990176
cloud_arrow_down = 990177
cloud_arrow_down_outline = 990178
cloud_arrow_left = 990179
cloud_arrow_left_outline = 990180
cloud_arrow_right = 990181
cloud_arrow_right_outline = 990182
cloud_arrow_up = 990183
cloud_arrow_up_outline = 990184
cloud_braces = 985013
cloud_cancel = 990185
cloud_cancel_outline = 990186
cloud_check = 990187
cloud_check_outline = 990188
cloud_check_variant = 983392
cloud_check_variant_outline = 987852
cloud_circle = 983393
cloud_circle_outline = 990189
cloud_clock = 990190
cloud_clock_outline = 990191
cloud_cog = 990192
cloud_cog_outline = 990193
cloud_download = 983394
cloud_download_outline = 985981
cloud_key = 990369
cloud_key_outline = 990370
cloud_lock = 987633
cloud_lock_open = 990194
cloud_lock_open_outline = 990195
cloud_lock_outline = 987634
cloud_minus = 990196
cloud_minus_outline = 990197
cloud_off = 990198
cloud_off_outline = 983396
cloud_outline = 983395
cloud_percent = 989749
cloud_percent_outline = 989750
cloud_plus = 990199
cloud_plus_outline = 990200
cloud_print = 983397
cloud_print_outline = 983398
cloud_question = 985657
cloud_question_outline = 990201
cloud_refresh = 990202
cloud_refresh_outline = 990203
cloud_refresh_variant = 984362
cloud_refresh_variant_outline = 990204
cloud_remove = 990205
cloud_remove_outline = 990206
cloud_search = 985430
cloud_search_outline = 985431
cloud_sync = 984639
cloud_sync_outline = 987862
cloud_tags = 985014
cloud_upload = 983399
cloud_upload_outline = 985982
clouds = 990101
clover = 985110
clover_outline = 990306
coach_lamp = 987168
coach_lamp_variant = 989751
coat_rack = 987294
code_array = 983400
code_block_braces = 990339
code_block_brackets = 990340
code_block_parentheses = 990341
code_block_tags = 990342
code_braces = 983401
code_braces_box = 987350
code_brackets = 983402
code_equal = 983403
code_greater_than = 983404
code_greater_than_or_equal = 983405
code_json = 984614
code_less_than = 983406
code_less_than_or_equal = 983407
code_not_equal = 983408
code_not_equal_variant = 983409
code_parentheses = 983410
code_parentheses_box = 987351
code_string = 983411
code_tags = 983412
code_tags_check = 984724
codepen = 983413
coffee = 983414
coffee_maker = 987295
coffee_maker_check = 989489
coffee_maker_check_outline = 989490
coffee_maker_outline = 989211
coffee_off = 987050
coffee_off_outline = 987051
coffee_outline = 984778
coffee_to_go = 983415
coffee_to_go_outline = 987918
coffin = 985983
cog = 984211
cog_box = 984212
cog_clockwise = 987613
cog_counterclockwise = 987614
cog_off = 988110
cog_off_outline = 988111
cog_outline = 985275
cog_pause = 989491
cog_pause_outline = 989492
cog_play = 989493
cog_play_outline = 989494
cog_refresh = 988254
cog_refresh_outline = 988255
cog_stop = 989495
cog_stop_outline = 989496
cog_sync = 988256
cog_sync_outline = 988257
cog_transfer = 987227
cog_transfer_outline = 987228
cogs = 985302
collage = 984640
collapse_all = 985766
collapse_all_outline = 985767
color_helper = 983417
comma = 986659
comma_box = 986667
comma_box_outline = 986660
comma_circle = 986661
comma_circle_outline = 986662
comment = 983418
comment_account = 983419
comment_account_outline = 983420
comment_alert = 983421
comment_alert_outline = 983422
comment_arrow_left = 985569
comment_arrow_left_outline = 985570
comment_arrow_right = 985571
comment_arrow_right_outline = 985572
comment_bookmark = 988590
comment_bookmark_outline = 988591
comment_check = 983423
comment_check_outline = 983424
comment_edit = 987583
comment_edit_outline = 987844
comment_eye = 985658
comment_eye_outline = 985659
comment_flash = 988592
comment_flash_outline = 988593
comment_minus = 988639
comment_minus_outline = 988640
comment_multiple = 985183
comment_multiple_outline = 983425
comment_off = 988641
comment_off_outline = 988642
comment_outline = 983426
comment_plus = 985573
comment_plus_outline = 983427
comment_processing = 983428
comment_processing_outline = 983429
comment_question = 985111
comment_question_outline = 983430
comment_quote = 987169
comment_quote_outline = 987170
comment_remove = 984542
comment_remove_outline = 983431
comment_search = 985660
comment_search_outline = 985661
comment_text = 983432
comment_text_multiple = 985184
comment_text_multiple_outline = 985185
comment_text_outline = 983433
compare = 983434
compare_horizontal = 988306
compare_remove = 989363
compare_vertical = 988307
compass = 983435
compass_off = 985984
compass_off_outline = 985985
compass_outline = 983436
compass_rose = 988034
compost = 989752
cone = 989516
cone_off = 989517
connection = 988694
console = 983437
console_line = 985015
console_network = 985257
console_network_outline = 986208
consolidate = 987352
contactless_payment = 986474
contactless_payment_circle = 983841
contactless_payment_circle_outline = 984072
contacts = 984779
contacts_outline = 984504
contain = 985662
contain_end = 985663
contain_start = 985664
content_copy = 983439
content_cut = 983440
content_duplicate = 983441
content_paste = 983442
content_save = 983443
content_save_alert = 986946
content_save_alert_outline = 986947
content_save_all = 983444
content_save_all_outline = 986948
content_save_check = 989418
content_save_check_outline = 989419
content_save_cog = 988251
content_save_cog_outline = 988252
content_save_edit = 986363
content_save_edit_outline = 986364
content_save_minus = 990019
content_save_minus_outline = 990020
content_save_move = 986663
content_save_move_outline = 986664
content_save_off = 988739
content_save_off_outline = 988740
content_save_outline = 985112
content_save_plus = 990017
content_save_plus_outline = 990018
content_save_settings = 984603
content_save_settings_outline = 985902
contrast = 983445
contrast_box = 983446
contrast_circle = 983447
controller = 983732
controller_classic = 985986
controller_classic_outline = 985987
controller_off = 983733
cookie = 983448
cookie_alert = 988880
cookie_alert_outline = 988881
cookie_check = 988882
cookie_check_outline = 988883
cookie_clock = 988900
cookie_clock_outline = 988901
cookie_cog = 988884
cookie_cog_outline = 988885
cookie_edit = 988902
cookie_edit_outline = 988903
cookie_lock = 988904
cookie_lock_outline = 988905
cookie_minus = 988890
cookie_minus_outline = 988891
cookie_off = 988906
cookie_off_outline = 988907
cookie_outline = 988894
cookie_plus = 988886
cookie_plus_outline = 988887
cookie_refresh = 988908
cookie_refresh_outline = 988909
cookie_remove = 988888
cookie_remove_outline = 988889
cookie_settings = 988892
cookie_settings_outline = 988893
coolant_temperature = 984008
copyleft = 989497
copyright = 984550
cordova = 985432
corn = 985016
corn_off = 988143
cosine_wave = 988281
counter = 983449
countertop = 989212
countertop_outline = 989213
cow = 983450
cow_off = 989436
cpu_32_bit = 986847
cpu_64_bit = 986848
cradle = 989579
cradle_outline = 989585
crane = 985186
creation = 984692
creation_outline = 990251
creative_commons = 986475
credit_card = 987119
credit_card_check = 988112
credit_card_check_outline = 988113
credit_card_chip = 989455
credit_card_chip_outline = 989456
credit_card_clock = 986849
credit_card_clock_outline = 986850
credit_card_edit = 989143
credit_card_edit_outline = 989144
credit_card_fast = 989457
credit_card_fast_outline = 989458
credit_card_lock = 989415
credit_card_lock_outline = 989416
credit_card_marker = 984744
credit_card_marker_outline = 986558
credit_card_minus = 987052
credit_card_minus_outline = 987053
credit_card_multiple = 987120
credit_card_multiple_outline = 983452
credit_card_off = 987121
credit_card_off_outline = 984548
credit_card_outline = 983451
credit_card_plus = 987122
credit_card_plus_outline = 984694
credit_card_refresh = 988741
credit_card_refresh_outline = 988742
credit_card_refund = 987123
credit_card_refund_outline = 985768
credit_card_remove = 987054
credit_card_remove_outline = 987055
credit_card_scan = 987124
credit_card_scan_outline = 983453
credit_card_search = 988743
credit_card_search_outline = 988744
credit_card_settings = 987125
credit_card_settings_outline = 985303
credit_card_sync = 988745
credit_card_sync_outline = 988746
credit_card_wireless = 985090
credit_card_wireless_off = 984442
credit_card_wireless_off_outline = 984443
credit_card_wireless_outline = 986476
cricket = 986477
crop = 983454
crop_free = 983455
crop_landscape = 983456
crop_portrait = 983457
crop_rotate = 984726
crop_square = 983458
cross = 985427
cross_bolnisi = 986349
cross_celtic = 986357
cross_outline = 986358
crosshairs = 983459
crosshairs_gps = 983460
crosshairs_off = 986949
crosshairs_question = 987446
crowd = 989557
crown = 983461
crown_circle = 989148
crown_circle_outline = 989149
crown_outline = 987600
cryengine = 985433
crystal_ball = 985903
cube = 983462
cube_off = 988188
cube_off_outline = 988189
cube_outline = 983463
cube_scan = 985988
cube_send = 983464
cube_unfolded = 983465
cup = 983466
cup_off = 984549
cup_off_outline = 988029
cup_outline = 987919
cup_water = 983467
cupboard = 986950
cupboard_outline = 986951
cupcake = 985434
curling = 985187
currency_bdt = 985188
currency_brl = 985989
currency_btc = 983468
currency_cny = 985018
currency_eth = 985019
currency_eur = 983469
currency_eur_off = 987925
currency_fra = 989753
currency_gbp = 983470
currency_ils = 986209
currency_inr = 983471
currency_jpy = 985020
currency_krw = 985021
currency_kzt = 985189
currency_mnt = 988434
currency_ngn = 983472
currency_php = 985574
currency_rial = 986780
currency_rub = 983473
currency_rupee = 989558
currency_sign = 985022
currency_thb = 990213
currency_try = 983474
currency_twd = 985023
currency_uah = 990107
currency_usd = 983489
currency_usd_off = 984698
current_ac = 988288
current_dc = 985436
cursor_default = 983488
cursor_default_click = 986365
cursor_default_click_outline = 986366
cursor_default_gesture = 987431
cursor_default_gesture_outline = 987432
cursor_default_outline = 983487
cursor_move = 983486
cursor_pointer = 983485
cursor_text = 984551
curtains = 989254
curtains_closed = 989255
cylinder = 989518
cylinder_off = 989519
dance_ballroom = 988667
dance_pole = 988536
data_matrix = 988476
data_matrix_edit = 988477
data_matrix_minus = 988478
data_matrix_plus = 988479
data_matrix_remove = 988480
data_matrix_scan = 988481
database = 983484
database_alert = 988730
database_alert_outline = 988708
database_arrow_down = 988731
database_arrow_down_outline = 988709
database_arrow_left = 988732
database_arrow_left_outline = 988710
database_arrow_right = 988733
database_arrow_right_outline = 988711
database_arrow_up = 988734
database_arrow_up_outline = 988712
database_check = 985769
database_check_outline = 988713
database_clock = 988735
database_clock_outline = 988714
database_cog = 988747
database_cog_outline = 988748
database_edit = 985990
database_edit_outline = 988715
database_export = 985438
database_export_outline = 988716
database_eye = 989471
database_eye_off = 989472
database_eye_off_outline = 989473
database_eye_outline = 989474
database_import = 985437
database_import_outline = 988717
database_lock = 985770
database_lock_outline = 988718
database_marker = 987894
database_marker_outline = 988719
database_minus = 983483
database_minus_outline = 988720
database_off = 988736
database_off_outline = 988721
database_outline = 988722
database_plus = 983482
database_plus_outline = 988723
database_refresh = 984514
database_refresh_outline = 988724
database_remove = 986368
database_remove_outline = 988725
database_search = 985190
database_search_outline = 988726
database_settings = 986369
database_settings_outline = 988727
database_sync = 986367
database_sync_outline = 988728
death_star = 985304
death_star_variant = 985305
deathly_hallows = 985991
debian = 985306
debug_step_into = 983481
debug_step_out = 983480
debug_step_over = 983479
decagram = 984940
decagram_outline = 984941
decimal = 987297
decimal_comma = 987298
decimal_comma_decrease = 987299
decimal_comma_increase = 987300
decimal_decrease = 983478
decimal_increase = 983477
delete = 983476
delete_alert = 987301
delete_alert_outline = 987302
delete_circle = 984707
delete_circle_outline = 985992
delete_clock = 988502
delete_clock_outline = 988503
delete_empty = 984780
delete_empty_outline = 986781
delete_forever = 984552
delete_forever_outline = 985993
delete_off = 987303
delete_off_outline = 987304
delete_outline = 985575
delete_restore = 985113
delete_sweep = 984553
delete_sweep_outline = 986210
delete_variant = 983475
delta = 983490
desk = 987705
desk_lamp = 985439
desk_lamp_off = 989983
desk_lamp_on = 989984
deskphone = 983491
desktop_classic = 985024
desktop_tower = 983493
desktop_tower_monitor = 985771
details = 983494
dev_to = 986478
developer_board = 984727
deviantart = 983495
devices = 987056
dharmachakra = 985419
diabetes = 987430
dialpad = 984604
diameter = 986211
diameter_outline = 986212
diameter_variant = 986213
diamond = 985994
diamond_outline = 985995
diamond_stone = 983496
dice_1 = 983498
dice_1_outline = 987466
dice_2 = 983499
dice_2_outline = 987467
dice_3 = 983500
dice_3_outline = 987468
dice_4 = 983501
dice_4_outline = 987469
dice_5 = 983502
dice_5_outline = 987470
dice_6 = 983503
dice_6_outline = 987471
dice_d10 = 987475
dice_d10_outline = 984943
dice_d12 = 987476
dice_d12_outline = 985191
dice_d20 = 987477
dice_d20_outline = 984554
dice_d4 = 987472
dice_d4_outline = 984555
dice_d6 = 987473
dice_d6_outline = 984557
dice_d8 = 987474
dice_d8_outline = 984556
dice_multiple = 984942
dice_multiple_outline = 987478
digital_ocean = 987703
dip_switch = 985025
directions = 983504
directions_fork = 984641
disc = 984558
disc_alert = 983505
disc_player = 985440
dishwasher = 985772
dishwasher_alert = 987576
dishwasher_off = 987577
disqus = 983506
distribute_horizontal_center = 987593
distribute_horizontal_left = 987592
distribute_horizontal_right = 987594
distribute_vertical_bottom = 987595
distribute_vertical_center = 987596
distribute_vertical_top = 987597
diversify = 989303
diving = 989559
diving_flippers = 986559
diving_helmet = 986560
diving_scuba = 990071
diving_scuba_flag = 986562
diving_scuba_mask = 986561
diving_scuba_tank = 986563
diving_scuba_tank_multiple = 986564
diving_snorkel = 986565
division = 983508
division_box = 983509
dlna = 985665
dna = 984708
dns = 983510
dns_outline = 985996
dock_bottom = 987305
dock_left = 987306
dock_right = 987307
dock_top = 988435
dock_window = 987308
docker = 985192
doctor = 985666
dog = 985667
dog_service = 985773
dog_side = 985668
dog_side_off = 988910
dolby = 984755
dolly = 986782
dolphin = 989364
domain = 983511
domain_off = 986479
domain_plus = 987309
domain_remove = 987310
domain_switch = 990252
dome_light = 988190
domino_mask = 987171
donkey = 985026
door = 985114
door_closed = 985115
door_closed_cancel = 990355
door_closed_lock = 987311
door_open = 985116
door_sliding = 989214
door_sliding_lock = 989215
door_sliding_open = 989216
doorbell = 987878
doorbell_video = 985193
dot_net = 985774
dots_circle = 989560
dots_grid = 988668
dots_hexagon = 988671
dots_horizontal = 983512
dots_horizontal_circle = 985027
dots_horizontal_circle_outline = 985997
dots_square = 988669
dots_triangle = 988670
dots_vertical = 983513
dots_vertical_circle = 985028
dots_vertical_circle_outline = 985998
download = 983514
download_box = 988258
download_box_outline = 988259
download_circle = 988260
download_circle_outline = 988261
download_lock = 987936
download_lock_outline = 987937
download_multiple = 985577
download_network = 984820
download_network_outline = 986214
download_off = 987312
download_off_outline = 987313
download_outline = 985999
drag = 983515
drag_horizontal = 983516
drag_horizontal_variant = 987888
drag_variant = 986000
drag_vertical = 983517
drag_vertical_variant = 987889
drama_masks = 986370
draw = 986953
draw_pen = 989625
drawing = 983518
drawing_box = 983519
dresser = 986954
dresser_outline = 986955
drone = 983522
dropbox = 983523
drupal = 983524
duck = 983525
dumbbell = 983526
dump_truck = 986215
ear_hearing = 985029
ear_hearing_loop = 989934
ear_hearing_off = 985669
earbuds = 989263
earbuds_off = 989264
earbuds_off_outline = 989265
earbuds_outline = 989266
earth = 983527
earth_arrow_down = 990343
earth_arrow_left = 990344
earth_arrow_right = 987921
earth_arrow_up = 990345
earth_box = 984781
earth_box_minus = 988167
earth_box_off = 984782
earth_box_plus = 988166
earth_box_remove = 988168
earth_minus = 988164
earth_off = 983528
earth_plus = 988163
earth_remove = 988165
egg = 985775
egg_easter = 985776
egg_fried = 989258
egg_off = 988144
egg_off_outline = 988145
egg_outline = 988146
eiffel_tower = 988523
eight_track = 985578
eject = 983530
eject_circle = 989987
eject_circle_outline = 989988
eject_outline = 986001
electric_switch = 986783
electric_switch_closed = 987353
electron_framework = 987172
elephant = 985030
elevation_decline = 983531
elevation_rise = 983532
elevator = 983533
elevator_down = 987842
elevator_passenger = 988033
elevator_passenger_off = 989561
elevator_passenger_off_outline = 989562
elevator_passenger_outline = 989563
elevator_up = 987841
ellipse = 986784
ellipse_outline = 986785
email = 983534
email_alert = 984783
email_alert_outline = 986434
email_arrow_left = 987354
email_arrow_left_outline = 987355
email_arrow_right = 987356
email_arrow_right_outline = 987357
email_box = 986371
email_check = 985777
email_check_outline = 985778
email_edit = 986851
email_edit_outline = 986852
email_fast = 989295
email_fast_outline = 989296
email_heart_outline = 990299
email_lock = 983537
email_lock_outline = 990049
email_mark_as_unread = 986002
email_minus = 986853
email_minus_outline = 986854
email_multiple = 986855
email_multiple_outline = 986856
email_newsletter = 987057
email_off = 988131
email_off_outline = 988132
email_open = 983535
email_open_heart_outline = 990300
email_open_multiple = 986857
email_open_multiple_outline = 986858
email_open_outline = 984559
email_outline = 983536
email_plus = 985579
email_plus_outline = 985580
email_remove = 988769
email_remove_outline = 988770
email_seal = 989531
email_seal_outline = 989532
email_search = 985441
email_search_outline = 985442
email_sync = 987847
email_sync_outline = 987848
email_variant = 984560
ember = 985904
emby = 984756
emoticon = 986216
emoticon_angry = 986217
emoticon_angry_outline = 986218
emoticon_confused = 987358
emoticon_confused_outline = 987359
emoticon_cool = 986219
emoticon_cool_outline = 983539
emoticon_cry = 986220
emoticon_cry_outline = 986221
emoticon_dead = 986222
emoticon_dead_outline = 984731
emoticon_devil = 986223
emoticon_devil_outline = 983540
emoticon_excited = 986224
emoticon_excited_outline = 984732
emoticon_frown = 986956
emoticon_frown_outline = 986957
emoticon_happy = 986225
emoticon_happy_outline = 983541
emoticon_kiss = 986226
emoticon_kiss_outline = 986227
emoticon_lol = 987668
emoticon_lol_outline = 987669
emoticon_minus = 990386
emoticon_minus_outline = 990387
emoticon_neutral = 986228
emoticon_neutral_outline = 983542
emoticon_outline = 983538
emoticon_plus = 990388
emoticon_plus_outline = 990389
emoticon_poop = 983543
emoticon_poop_outline = 986229
emoticon_remove = 990390
emoticon_remove_outline = 990391
emoticon_sad = 986230
emoticon_sad_outline = 983544
emoticon_sick = 988540
emoticon_sick_outline = 988541
emoticon_tongue = 983545
emoticon_tongue_outline = 986231
emoticon_wink = 986232
emoticon_wink_outline = 986233
engine = 983546
engine_off = 985670
engine_off_outline = 985671
engine_outline = 983547
epsilon = 987360
equal = 983548
equal_box = 983549
equalizer = 986786
equalizer_outline = 986787
eraser = 983550
eraser_variant = 984642
escalator = 983551
escalator_box = 988057
escalator_down = 987840
escalator_up = 987839
eslint = 986234
et = 985779
ethereum = 985194
ethernet = 983552
ethernet_cable = 983553
ethernet_cable_off = 983554
ev_plug_ccs1 = 988441
ev_plug_ccs2 = 988442
ev_plug_chademo = 988443
ev_plug_tesla = 988444
ev_plug_type1 = 988445
ev_plug_type2 = 988446
ev_station = 984561
evernote = 983556
excavator = 987173
exclamation = 983557
exclamation_thick = 987704
exit_run = 985672
exit_to_app = 983558
expand_all = 985780
expand_all_outline = 985781
expansion_card = 985262
expansion_card_variant = 987058
exponent = 985443
exponent_box = 985444
export = 983559
export_variant = 986003
eye = 983560
eye_arrow_left = 989437
eye_arrow_left_outline = 989438
eye_arrow_right = 989439
eye_arrow_right_outline = 989440
eye_check = 986372
eye_check_outline = 986373
eye_circle = 986004
eye_circle_outline = 986005
eye_closed = 990371
eye_lock = 990214
eye_lock_open = 990215
eye_lock_open_outline = 990216
eye_lock_outline = 990217
eye_minus = 987174
eye_minus_outline = 987175
eye_off = 983561
eye_off_outline = 984785
eye_outline = 984784
eye_plus = 985195
eye_plus_outline = 985196
eye_refresh = 989564
eye_refresh_outline = 989565
eye_remove = 988643
eye_remove_outline = 988644
eye_settings = 985197
eye_settings_outline = 985198
eyedropper = 983562
eyedropper_minus = 988125
eyedropper_off = 988127
eyedropper_plus = 988124
eyedropper_remove = 988126
eyedropper_variant = 983563
face_agent = 986480
face_man = 984643
face_man_outline = 986006
face_man_profile = 984644
face_man_shimmer = 988620
face_man_shimmer_outline = 988621
face_mask = 988550
face_mask_outline = 988551
face_recognition = 986235
face_woman = 987255
face_woman_outline = 987256
face_woman_profile = 987254
face_woman_shimmer = 988622
face_woman_shimmer_outline = 988623
facebook = 983564
facebook_gaming = 985053
facebook_messenger = 983566
facebook_workplace = 985905
factory = 983567
family_tree = 988686
fan = 983568
fan_alert = 988268
fan_auto = 988957
fan_chevron_down = 988269
fan_chevron_up = 988270
fan_clock = 989754
fan_minus = 988272
fan_off = 985117
fan_plus = 988271
fan_remove = 988273
fan_speed_1 = 988274
fan_speed_2 = 988275
fan_speed_3 = 988276
fast_forward = 983569
fast_forward_10 = 986481
fast_forward_15 = 989498
fast_forward_30 = 986374
fast_forward_45 = 989970
fast_forward_5 = 987640
fast_forward_60 = 988683
fast_forward_outline = 984786
faucet = 989993
faucet_variant = 989994
fax = 983570
feather = 984787
feature_search = 985673
feature_search_outline = 985674
fedora = 985307
fence = 989082
fence_electric = 989174
fencing = 988353
ferris_wheel = 986788
ferry = 983571
file = 983572
file_account = 984891
file_account_outline = 987176
file_alert = 985675
file_alert_outline = 985676
file_arrow_left_right = 989843
file_arrow_left_right_outline = 989844
file_arrow_up_down = 989845
file_arrow_up_down_outline = 989846
file_cabinet = 985782
file_cad = 986859
file_cad_box = 986860
file_cancel = 986566
file_cancel_outline = 986567
file_certificate = 987526
file_certificate_outline = 987527
file_chart = 983573
file_chart_check = 989638
file_chart_check_outline = 989639
file_chart_outline = 987177
file_check = 983574
file_check_outline = 986665
file_clock = 987873
file_clock_outline = 987874
file_cloud = 983575
file_cloud_outline = 987178
file_code = 983598
file_code_outline = 987179
file_cog = 987259
file_cog_outline = 987260
file_compare = 985258
file_delimited = 983576
file_delimited_outline = 986789
file_document = 983577
file_document_alert = 989847
file_document_alert_outline = 989848
file_document_arrow_right = 990223
file_document_arrow_right_outline = 990224
file_document_check = 989849
file_document_check_outline = 989850
file_document_edit = 986568
file_document_edit_outline = 986569
file_document_minus = 989851
file_document_minus_outline = 989852
file_document_multiple = 988439
file_document_multiple_outline = 988440
file_document_outline = 985582
file_document_plus = 989853
file_document_plus_outline = 989854
file_document_refresh = 990330
file_document_refresh_outline = 990331
file_document_remove = 989855
file_document_remove_outline = 989856
file_download = 985445
file_download_outline = 985446
file_edit = 987623
file_edit_outline = 987624
file_excel = 983579
file_excel_box = 983580
file_excel_box_outline = 987180
file_excel_outline = 987181
file_export = 983581
file_export_outline = 987182
file_eye = 986570
file_eye_outline = 986571
file_find = 983582
file_find_outline = 986007
file_gif_box = 986488
file_hidden = 984595
file_image = 983583
file_image_marker = 989042
file_image_marker_outline = 989043
file_image_minus = 989499
file_image_minus_outline = 989500
file_image_outline = 986800
file_image_plus = 989501
file_image_plus_outline = 989502
file_image_remove = 989503
file_image_remove_outline = 989504
file_import = 983584
file_import_outline = 987183
file_jpg_box = 983589
file_key = 987524
file_key_outline = 987525
file_link = 987511
file_link_outline = 987512
file_lock = 983585
file_lock_open = 989640
file_lock_open_outline = 989641
file_lock_outline = 987184
file_marker = 989044
file_marker_outline = 989045
file_minus = 989857
file_minus_outline = 989858
file_move = 985785
file_move_outline = 987185
file_multiple = 983586
file_multiple_outline = 987186
file_music = 983587
file_music_outline = 986666
file_outline = 983588
file_pdf_box = 983590
file_percent = 985118
file_percent_outline = 987187
file_phone = 987513
file_phone_outline = 987514
file_plus = 984914
file_plus_outline = 986861
file_png_box = 986669
file_powerpoint = 983591
file_powerpoint_box = 983592
file_powerpoint_box_outline = 987188
file_powerpoint_outline = 987189
file_presentation_box = 983593
file_question = 985199
file_question_outline = 987190
file_refresh = 985368
file_refresh_outline = 984385
file_remove = 986008
file_remove_outline = 987191
file_replace = 985906
file_replace_outline = 985907
file_restore = 984688
file_restore_outline = 987192
file_rotate_left = 989755
file_rotate_left_outline = 989756
file_rotate_right = 989757
file_rotate_right_outline = 989758
file_search = 986236
file_search_outline = 986237
file_send = 983594
file_send_outline = 987193
file_settings = 987257
file_settings_outline = 987258
file_sign = 989635
file_star = 987194
file_star_four_points = 990253
file_star_four_points_outline = 990254
file_star_outline = 987195
file_swap = 987060
file_swap_outline = 987061
file_sync = 987670
file_sync_outline = 987671
file_table = 986238
file_table_box = 987361
file_table_box_multiple = 987362
file_table_box_multiple_outline = 987363
file_table_box_outline = 987364
file_table_outline = 986239
file_tree = 984645
file_tree_outline = 988114
file_undo = 985308
file_undo_outline = 987196
file_upload = 985677
file_upload_outline = 985678
file_video = 983595
file_video_outline = 986668
file_word = 983596
file_word_box = 983597
file_word_box_outline = 987197
file_word_outline = 987198
file_xml_box = 990027
film = 983599
filmstrip = 983600
filmstrip_box = 983858
filmstrip_box_multiple = 986392
filmstrip_off = 983601
filter = 983602
filter_check = 989420
filter_check_outline = 989421
filter_cog = 989859
filter_cog_outline = 989860
filter_menu = 987365
filter_menu_outline = 987366
filter_minus = 986862
filter_minus_outline = 986863
filter_multiple = 989759
filter_multiple_outline = 989760
filter_off = 988399
filter_off_outline = 988400
filter_outline = 983603
filter_plus = 986864
filter_plus_outline = 986865
filter_remove = 983604
filter_remove_outline = 983605
filter_settings = 989861
filter_settings_outline = 989862
filter_variant = 983606
filter_variant_minus = 987410
filter_variant_plus = 987411
filter_variant_remove = 987199
finance = 985119
find_replace = 984788
fingerprint = 983607
fingerprint_off = 986801
fire = 983608
fire_alert = 988631
fire_circle = 989191
fire_extinguisher = 986866
fire_hydrant = 987447
fire_hydrant_alert = 987448
fire_hydrant_off = 987449
fire_off = 988962
fire_station = 990403
fire_truck = 985259
firebase = 985447
firefox = 983609
fireplace = 986670
fireplace_off = 986671
firewire = 984510
firework = 986672
firework_off = 988963
fish = 983610
fish_off = 988147
fishbowl = 986867
fishbowl_outline = 986868
fit_to_page = 986869
fit_to_page_outline = 986870
fit_to_screen = 989428
fit_to_screen_outline = 989429
flag = 983611
flag_checkered = 983612
flag_minus = 986009
flag_minus_outline = 987314
flag_off = 989422
flag_off_outline = 989423
flag_outline = 983613
flag_plus = 986010
flag_plus_outline = 987315
flag_remove = 986011
flag_remove_outline = 987316
flag_triangle = 983615
flag_variant = 983616
flag_variant_minus = 990132
flag_variant_minus_outline = 990133
flag_variant_off = 990128
flag_variant_off_outline = 990129
flag_variant_outline = 983614
flag_variant_plus = 990130
flag_variant_plus_outline = 990131
flag_variant_remove = 990134
flag_variant_remove_outline = 990135
flare = 986482
flash = 983617
flash_alert = 986871
flash_alert_outline = 986872
flash_auto = 983618
flash_off = 983619
flash_off_outline = 990021
flash_outline = 984789
flash_red_eye = 984699
flash_triangle = 989981
flash_triangle_outline = 989982
flashlight = 983620
flashlight_off = 983621
flask = 983187
flask_empty = 983188
flask_empty_minus = 987706
flask_empty_minus_outline = 987707
flask_empty_off = 988148
flask_empty_off_outline = 988149
flask_empty_outline = 983189
flask_empty_plus = 987708
flask_empty_plus_outline = 987709
flask_empty_remove = 987710
flask_empty_remove_outline = 987711
flask_minus = 987712
flask_minus_outline = 987713
flask_off = 988150
flask_off_outline = 988151
flask_outline = 983190
flask_plus = 987714
flask_plus_outline = 987715
flask_remove = 987716
flask_remove_outline = 987717
flask_round_bottom = 987723
flask_round_bottom_empty = 987724
flask_round_bottom_empty_outline = 987725
flask_round_bottom_outline = 987726
fleur_de_lis = 987907
flip_horizontal = 987367
flip_to_back = 983623
flip_to_front = 983624
flip_vertical = 987368
floor_lamp = 985309
floor_lamp_dual = 987200
floor_lamp_dual_outline = 989134
floor_lamp_outline = 989128
floor_lamp_torchiere = 988999
floor_lamp_torchiere_outline = 989142
floor_lamp_torchiere_variant = 987201
floor_lamp_torchiere_variant_outline = 989135
floor_plan = 985121
floppy = 983625
floppy_variant = 985583
flower = 983626
flower_outline = 985584
flower_pollen = 989317
flower_pollen_outline = 989318
flower_poppy = 986376
flower_tulip = 985585
flower_tulip_outline = 985586
focus_auto = 986958
focus_field = 986959
focus_field_horizontal = 986960
focus_field_vertical = 986961
folder = 983627
folder_account = 983628
folder_account_outline = 986012
folder_alert = 986572
folder_alert_outline = 986573
folder_arrow_down = 989672
folder_arrow_down_outline = 989673
folder_arrow_left = 989674
folder_arrow_left_outline = 989675
folder_arrow_left_right = 989676
folder_arrow_left_right_outline = 989677
folder_arrow_right = 989678
folder_arrow_right_outline = 989679
folder_arrow_up = 989680
folder_arrow_up_down = 989681
folder_arrow_up_down_outline = 989682
folder_arrow_up_outline = 989683
folder_cancel = 989684
folder_cancel_outline = 989685
folder_check = 989566
folder_check_outline = 989567
folder_clock = 985786
folder_clock_outline = 985787
folder_cog = 987263
folder_cog_outline = 987264
folder_download = 983629
folder_download_outline = 987369
folder_edit = 985310
folder_edit_outline = 986574
folder_eye = 989066
folder_eye_outline = 989067
folder_file = 989686
folder_file_outline = 989687
folder_google_drive = 983630
folder_heart = 987370
folder_heart_outline = 987371
folder_hidden = 989086
folder_home = 987317
folder_home_outline = 987318
folder_image = 983631
folder_information = 987319
folder_information_outline = 987320
folder_key = 985260
folder_key_network = 985261
folder_key_network_outline = 986240
folder_key_outline = 987372
folder_lock = 983632
folder_lock_open = 983633
folder_lock_open_outline = 989863
folder_lock_outline = 989864
folder_marker = 987757
folder_marker_outline = 987758
folder_minus = 990025
folder_minus_outline = 990026
folder_move = 983634
folder_move_outline = 987718
folder_multiple = 983635
folder_multiple_image = 983636
folder_multiple_outline = 983637
folder_multiple_plus = 988286
folder_multiple_plus_outline = 988287
folder_music = 987993
folder_music_outline = 987994
folder_network = 985200
folder_network_outline = 986241
folder_off = 989688
folder_off_outline = 989689
folder_open = 984944
folder_open_outline = 986575
folder_outline = 983638
folder_play = 989690
folder_play_outline = 989691
folder_plus = 983639
folder_plus_outline = 986013
folder_pound = 986377
folder_pound_outline = 986378
folder_question = 989642
folder_question_outline = 989643
folder_refresh = 984905
folder_refresh_outline = 984386
folder_remove = 983640
folder_remove_outline = 986014
folder_search = 985448
folder_search_outline = 985449
folder_settings = 987261
folder_settings_outline = 987262
folder_star = 984733
folder_star_multiple = 988115
folder_star_multiple_outline = 988116
folder_star_outline = 986015
folder_swap = 987062
folder_swap_outline = 987063
folder_sync = 986379
folder_sync_outline = 986380
folder_table = 987875
folder_table_outline = 987876
folder_text = 986242
folder_text_outline = 986243
folder_upload = 983641
folder_upload_outline = 987373
folder_wrench = 989692
folder_wrench_outline = 989693
folder_zip = 984811
folder_zip_outline = 985017
font_awesome = 983098
food = 983642
food_apple = 983643
food_apple_outline = 986244
food_croissant = 985032
food_drumstick = 988191
food_drumstick_off = 988264
food_drumstick_off_outline = 988265
food_drumstick_outline = 988192
food_fork_drink = 984562
food_halal = 988530
food_hot_dog = 989259
food_kosher = 988531
food_off = 984563
food_off_outline = 989461
food_outline = 989462
food_steak = 988266
food_steak_off = 988267
food_takeout_box = 989238
food_takeout_box_outline = 989239
food_turkey = 988956
food_variant = 983644
food_variant_off = 988133
foot_print = 986962
football = 983645
football_australian = 983646
football_helmet = 983647
forest = 989335
forest_outline = 990307
forklift = 985033
form_dropdown = 988160
form_select = 988161
form_textarea = 987285
form_textbox = 984590
form_textbox_lock = 987997
form_textbox_password = 985077
format_align_bottom = 984915
format_align_center = 983648
format_align_justify = 983649
format_align_left = 983650
format_align_middle = 984916
format_align_right = 983651
format_align_top = 984917
format_annotation_minus = 985788
format_annotation_plus = 984646
format_bold = 983652
format_clear = 983653
format_color_fill = 983654
format_color_highlight = 986673
format_color_marker_cancel = 987923
format_color_text = 984734
format_columns = 985311
format_float_center = 983655
format_float_left = 983656
format_float_none = 983657
format_float_right = 983658
format_font = 984790
format_font_size_decrease = 985587
format_font_size_increase = 985588
format_header_1 = 983659
format_header_2 = 983660
format_header_3 = 983661
format_header_4 = 983662
format_header_5 = 983663
format_header_6 = 983664
format_header_decrease = 983665
format_header_equal = 983666
format_header_increase = 983667
format_header_pound = 983668
format_horizontal_align_center = 984606
format_horizontal_align_left = 984607
format_horizontal_align_right = 984608
format_indent_decrease = 983669
format_indent_increase = 983670
format_italic = 983671
format_letter_case = 985908
format_letter_case_lower = 985909
format_letter_case_upper = 985910
format_letter_ends_with = 987064
format_letter_matches = 987065
format_letter_spacing = 989526
format_letter_spacing_variant = 989947
format_letter_starts_with = 987066
format_line_height = 989948
format_line_spacing = 983672
format_line_style = 984520
format_line_weight = 984521
format_list_bulleted = 983673
format_list_bulleted_square = 986576
format_list_bulleted_triangle = 986802
format_list_bulleted_type = 983674
format_list_checkbox = 985450
format_list_checks = 984918
format_list_group = 989280
format_list_group_plus = 990038
format_list_numbered = 983675
format_list_numbered_rtl = 986381
format_list_text = 987759
format_overline = 986803
format_page_break = 984791
format_page_split = 989463
format_paint = 983676
format_paragraph = 983677
format_paragraph_spacing = 989949
format_pilcrow = 984792
format_pilcrow_arrow_left = 983686
format_pilcrow_arrow_right = 983685
format_quote_close = 983678
format_quote_close_outline = 987560
format_quote_open = 984919
format_quote_open_outline = 987559
format_rotate_90 = 984746
format_section = 984735
format_size = 983679
format_strikethrough = 983680
format_strikethrough_variant = 983681
format_subscript = 983682
format_superscript = 983683
format_text = 983684
format_text_rotation_angle_down = 987067
format_text_rotation_angle_up = 987068
format_text_rotation_down = 986483
format_text_rotation_down_vertical = 987069
format_text_rotation_none = 986484
format_text_rotation_up = 987070
format_text_rotation_vertical = 987071
format_text_variant = 986674
format_text_variant_outline = 988431
format_text_wrapping_clip = 986382
format_text_wrapping_overflow = 986383
format_text_wrapping_wrap = 986384
format_textbox = 986385
format_title = 984564
format_underline = 983687
format_underline_wavy = 989417
format_vertical_align_bottom = 984609
format_vertical_align_center = 984610
format_vertical_align_top = 984611
format_wrap_inline = 983688
format_wrap_square = 983689
format_wrap_tight = 983690
format_wrap_top_bottom = 983691
forum = 983692
forum_minus = 989865
forum_minus_outline = 989866
forum_outline = 985122
forum_plus = 989867
forum_plus_outline = 989868
forum_remove = 989869
forum_remove_outline = 989870
forward = 983693
forwardburger = 986485
fountain = 985451
fountain_pen = 986386
fountain_pen_tip = 986387
fraction_one_half = 989586
freebsd = 985312
french_fries = 989527
frequently_asked_questions = 986804
fridge = 983696
fridge_alert = 987569
fridge_alert_outline = 987570
fridge_bottom = 983698
fridge_industrial = 988654
fridge_industrial_alert = 988655
fridge_industrial_alert_outline = 988656
fridge_industrial_off = 988657
fridge_industrial_off_outline = 988658
fridge_industrial_outline = 988659
fridge_off = 987567
fridge_off_outline = 987568
fridge_outline = 983695
fridge_top = 983697
fridge_variant = 988660
fridge_variant_alert = 988661
fridge_variant_alert_outline = 988662
fridge_variant_off = 988663
fridge_variant_off_outline = 988664
fridge_variant_outline = 988665
fruit_cherries = 987202
fruit_cherries_off = 988152
fruit_citrus = 987203
fruit_citrus_off = 988153
fruit_grapes = 987204
fruit_grapes_outline = 987205
fruit_pear = 989710
fruit_pineapple = 987206
fruit_watermelon = 987207
fuel = 985034
fuel_cell = 989365
fullscreen = 983699
fullscreen_exit = 983700
function = 983701
function_variant = 985201
furigana_horizontal = 987265
furigana_vertical = 987266
fuse = 986245
fuse_alert = 988205
fuse_blade = 986246
fuse_off = 988204
gamepad = 983702
gamepad_circle = 986675
gamepad_circle_down = 986676
gamepad_circle_left = 986677
gamepad_circle_outline = 986678
gamepad_circle_right = 986679
gamepad_circle_up = 986680
gamepad_down = 986681
gamepad_left = 986682
gamepad_outline = 989465
gamepad_right = 986683
gamepad_round = 986684
gamepad_round_down = 986685
gamepad_round_left = 986686
gamepad_round_outline = 986687
gamepad_round_right = 986688
gamepad_round_up = 986689
gamepad_square = 986805
gamepad_square_outline = 986806
gamepad_up = 986690
gamepad_variant = 983703
gamepad_variant_outline = 986807
gamma = 987374
gantry_crane = 986577
garage = 984793
garage_alert = 985202
garage_alert_variant = 987861
garage_lock = 989179
garage_open = 984794
garage_open_variant = 987860
garage_variant = 987859
garage_variant_lock = 989180
gas_burner = 989723
gas_cylinder = 984647
gas_station = 983704
gas_station_in_use = 990404
gas_station_in_use_outline = 990405
gas_station_off = 988169
gas_station_off_outline = 988170
gas_station_outline = 986808
gate = 983705
gate_alert = 989176
gate_and = 985313
gate_arrow_left = 989175
gate_arrow_right = 987497
gate_buffer = 989950
gate_nand = 985314
gate_nor = 985315
gate_not = 985316
gate_open = 987498
gate_or = 985317
gate_xnor = 985318
gate_xor = 985319
gatsby = 986691
gauge = 983706
gauge_empty = 985203
gauge_full = 985204
gauge_low = 985205
gavel = 983707
gender_female = 983708
gender_male = 983709
gender_male_female = 983710
gender_male_female_variant = 987455
gender_non_binary = 987456
gender_transgender = 983711
generator_mobile = 990346
generator_portable = 990347
generator_stationary = 990348
gentoo = 985320
gesture = 985035
gesture_double_tap = 984892
gesture_pinch = 985789
gesture_spread = 985790
gesture_swipe = 986486
gesture_swipe_down = 984893
gesture_swipe_horizontal = 985791
gesture_swipe_left = 984894
gesture_swipe_right = 984895
gesture_swipe_up = 984896
gesture_swipe_vertical = 985792
gesture_tap = 984897
gesture_tap_box = 987817
gesture_tap_button = 987816
gesture_tap_hold = 986487
gesture_two_double_tap = 984898
gesture_two_tap = 984899
ghost = 983712
ghost_off = 985589
ghost_off_outline = 988764
ghost_outline = 988765
gift = 986692
gift_off = 988911
gift_off_outline = 988912
gift_open = 988913
gift_open_outline = 988914
gift_outline = 983713
git = 983714
github = 983716
gitlab = 986016
glass_cocktail = 983894
glass_cocktail_off = 988646
glass_flute = 983717
glass_fragile = 989299
glass_mug = 983718
glass_mug_off = 988647
glass_mug_variant = 987414
glass_mug_variant_off = 988648
glass_pint_outline = 987917
glass_stange = 983719
glass_tulip = 983720
glass_wine = 985206
glasses = 983722
globe_light = 984687
globe_light_outline = 987863
globe_model = 985321
gmail = 983723
gnome = 983724
go_kart = 986489
go_kart_track = 986490
gog = 986017
gold = 987727
golf = 985123
golf_cart = 987556
golf_tee = 987267
gondola = 984710
goodreads = 986491
google = 983725
google_ads = 986247
google_analytics = 985036
google_assistant = 985037
google_cardboard = 983726
google_chrome = 983727
google_circles = 983728
google_circles_communities = 983729
google_circles_extended = 983730
google_circles_group = 983731
google_classroom = 983744
google_cloud = 987638
google_downasaur = 988002
google_drive = 983734
google_earth = 983735
google_fit = 985452
google_glass = 983736
google_hangouts = 983753
google_keep = 984796
google_lens = 985590
google_maps = 984565
google_my_business = 987208
google_nearby = 983737
google_play = 983740
google_plus = 983741
google_podcast = 986809
google_spreadsheet = 985591
google_street_view = 986248
google_translate = 983743
gradient_horizontal = 989002
gradient_vertical = 984736
grain = 986492
graph = 987209
graph_outline = 987210
graphql = 985207
grass = 988432
grave_stone = 986018
grease_pencil = 984648
greater_than = 985453
greater_than_or_equal = 985454
greenhouse = 983085
grid = 983745
grid_large = 984920
grid_off = 983746
grill = 986693
grill_outline = 987530
group = 983747
guitar_acoustic = 984945
guitar_electric = 983748
guitar_pick = 983749
guitar_pick_outline = 983750
guy_fawkes_mask = 985125
gymnastics = 989761
hail = 985793
hair_dryer = 987375
hair_dryer_outline = 987376
halloween = 986019
hamburger = 984709
hamburger_check = 989046
hamburger_minus = 989047
hamburger_off = 989048
hamburger_plus = 989049
hamburger_remove = 989050
hammer = 985322
hammer_screwdriver = 987938
hammer_sickle = 989319
hammer_wrench = 987939
hand_back_left = 986694
hand_back_left_off = 989232
hand_back_left_off_outline = 989234
hand_back_left_outline = 989228
hand_back_right = 986695
hand_back_right_off = 989233
hand_back_right_off_outline = 989235
hand_back_right_outline = 989229
hand_clap = 989515
hand_clap_off = 989762
hand_coin = 989327
hand_coin_outline = 989328
hand_cycle = 990108
hand_extended = 989366
hand_extended_outline = 989367
hand_front_left = 989227
hand_front_left_outline = 989230
hand_front_right = 985679
hand_front_right_outline = 989231
hand_heart = 987377
hand_heart_outline = 988542
hand_okay = 985680
hand_peace = 985681
hand_peace_variant = 985682
hand_pointing_down = 985683
hand_pointing_left = 985684
hand_pointing_right = 983751
hand_pointing_up = 985685
hand_saw = 986696
hand_wash = 988543
hand_wash_outline = 988544
hand_water = 988063
hand_wave = 989217
hand_wave_outline = 989218
handball = 986963
handcuffs = 987454
hands_pray = 984441
handshake = 987672
handshake_outline = 988577
hanger = 983752
hard_hat = 985455
harddisk = 983754
harddisk_plus = 987211
harddisk_remove = 987212
hat_fedora = 986020
hazard_lights = 986249
hdmi_port = 990136
hdr = 986493
hdr_off = 986494
head = 987998
head_alert = 987960
head_alert_outline = 987961
head_check = 987962
head_check_outline = 987963
head_cog = 987964
head_cog_outline = 987965
head_dots_horizontal = 987966
head_dots_horizontal_outline = 987967
head_flash = 987968
head_flash_outline = 987969
head_heart = 987970
head_heart_outline = 987971
head_lightbulb = 987972
head_lightbulb_outline = 987973
head_minus = 987974
head_minus_outline = 987975
head_outline = 987999
head_plus = 987976
head_plus_outline = 987977
head_question = 987978
head_question_outline = 987979
head_remove = 987980
head_remove_outline = 987981
head_snowflake = 987982
head_snowflake_outline = 987983
head_sync = 987984
head_sync_outline = 987985
headphones = 983755
headphones_bluetooth = 985456
headphones_box = 983756
headphones_off = 985038
headphones_settings = 983757
headset = 983758
headset_dock = 983759
headset_off = 983760
heart = 983761
heart_box = 983762
heart_box_outline = 983763
heart_broken = 983764
heart_broken_outline = 986388
heart_circle = 985457
heart_circle_outline = 985458
heart_cog = 988771
heart_cog_outline = 988772
heart_flash = 986873
heart_half = 984799
heart_half_full = 984798
heart_half_outline = 984800
heart_minus = 988207
heart_minus_outline = 988210
heart_multiple = 985686
heart_multiple_outline = 985687
heart_off = 984921
heart_off_outline = 988212
heart_outline = 983765
heart_plus = 988206
heart_plus_outline = 988209
heart_pulse = 984566
heart_remove = 988208
heart_remove_outline = 988211
heart_search = 990349
heart_settings = 988773
heart_settings_outline = 988774
heat_pump = 989763
heat_pump_outline = 989764
heat_wave = 989765
heating_coil = 989871
helicopter = 985794
help = 983766
help_box = 984971
help_box_multiple = 990218
help_box_multiple_outline = 990219
help_box_outline = 990220
help_circle = 983767
help_circle_outline = 984613
help_network = 984821
help_network_outline = 986250
help_rhombus = 986021
help_rhombus_outline = 986022
hexadecimal = 987815
hexagon = 983768
hexagon_multiple = 984801
hexagon_multiple_outline = 987378
hexagon_outline = 983769
hexagon_slice_1 = 985795
hexagon_slice_2 = 985796
hexagon_slice_3 = 985797
hexagon_slice_4 = 985798
hexagon_slice_5 = 985799
hexagon_slice_6 = 985800
hexagram = 985801
hexagram_outline = 985802
high_definition = 985039
high_definition_box = 985208
highway = 984567
hiking = 986495
history = 983770
hockey_puck = 985209
hockey_sticks = 985210
hololens = 983771
home = 983772
home_account = 985126
home_alert = 985211
home_alert_outline = 988624
home_analytics = 986810
home_assistant = 985040
home_automation = 985041
home_battery = 989441
home_battery_outline = 989442
home_circle = 985042
home_circle_outline = 987213
home_city = 986389
home_city_outline = 986390
home_clock = 989714
home_clock_outline = 989715
home_edit = 987481
home_edit_outline = 987482
home_export_outline = 987035
home_flood = 986874
home_floor_0 = 986578
home_floor_1 = 986496
home_floor_2 = 986497
home_floor_3 = 986498
home_floor_a = 986499
home_floor_b = 986500
home_floor_g = 986501
home_floor_l = 986502
home_floor_negative_1 = 986579
home_group = 986580
home_group_minus = 989633
home_group_plus = 989632
home_group_remove = 989634
home_heart = 985127
home_import_outline = 987036
home_lightbulb = 987729
home_lightbulb_outline = 987730
home_lightning_bolt = 989443
home_lightning_bolt_outline = 989444
home_lock = 985323
home_lock_open = 985324
home_map_marker = 984568
home_minus = 985460
home_minus_outline = 988117
home_modern = 983773
home_off = 989766
home_off_outline = 989767
home_outline = 984737
home_percent = 990332
home_percent_outline = 990333
home_plus = 985461
home_plus_outline = 988118
home_remove = 987719
home_remove_outline = 988119
home_roof = 987435
home_search = 988080
home_search_outline = 988081
home_silo = 990112
home_silo_outline = 990113
home_sound_in = 990255
home_sound_in_outline = 990256
home_sound_out = 990257
home_sound_out_outline = 990258
home_switch = 989076
home_switch_outline = 989077
home_thermometer = 986964
home_thermometer_outline = 986965
home_variant = 983774
home_variant_outline = 986023
hook = 984802
hook_off = 984803
hoop_house = 986710
hops = 983775
horizontal_rotate_clockwise = 987379
horizontal_rotate_counterclockwise = 987380
horse = 988607
horse_human = 988608
horse_variant = 988609
horse_variant_fast = 989294
horseshoe = 985688
hospital = 987126
hospital_box = 983776
hospital_box_outline = 987127
hospital_building = 983777
hospital_marker = 983778
hot_tub = 985128
hours_12 = 990356
hours_24 = 988280
hub = 990357
hub_outline = 990358
hubspot = 986391
hulu = 985129
human = 983782
human_baby_changing_table = 988043
human_cane = 988545
human_capacity_decrease = 988571
human_capacity_increase = 988572
human_child = 983783
human_dolly = 989568
human_edit = 988392
human_female = 984649
human_female_boy = 985689
human_female_dance = 988617
human_female_female = 985690
human_female_female_child = 990350
human_female_girl = 985691
human_greeting = 989124
human_greeting_proximity = 988573
human_greeting_variant = 984650
human_handsdown = 984651
human_handsup = 984652
human_male = 984653
human_male_board = 985232
human_male_board_poll = 985158
human_male_boy = 985692
human_male_child = 988044
human_male_female = 983784
human_male_female_child = 989219
human_male_girl = 985693
human_male_height = 986875
human_male_height_variant = 986876
human_male_male = 985694
human_male_male_child = 990351
human_non_binary = 989256
human_pregnant = 984527
human_queue = 988529
human_scooter = 987625
human_walker = 990065
human_wheelchair = 988045
human_white_cane = 989569
humble_bundle = 984900
hvac = 987986
hvac_off = 988574
hydraulic_oil_level = 987940
hydraulic_oil_temperature = 987941
hydro_power = 987877
hydrogen_station = 989332
ice_cream = 985130
ice_cream_off = 986706
ice_pop = 986877
id_card = 987072
identifier = 986878
ideogram_cjk = 987953
ideogram_cjk_variant = 987954
image = 983785
image_album = 983786
image_area = 983787
image_area_close = 983788
image_auto_adjust = 987073
image_broken = 983789
image_broken_variant = 983790
image_check = 989989
image_check_outline = 989990
image_edit = 987619
image_edit_outline = 987620
image_filter_black_white = 983792
image_filter_center_focus = 983793
image_filter_center_focus_strong = 986879
image_filter_center_focus_strong_outline = 986880
image_filter_center_focus_weak = 983794
image_filter_drama = 983795
image_filter_drama_outline = 990207
image_filter_frames = 983796
image_filter_hdr = 983797
image_filter_hdr_outline = 990308
image_filter_none = 983798
image_filter_tilt_shift = 983799
image_filter_vintage = 983800
image_frame = 986697
image_lock = 989872
image_lock_outline = 989873
image_marker = 989051
image_marker_outline = 989052
image_minus = 988185
image_minus_outline = 990023
image_move = 985592
image_multiple = 983801
image_multiple_outline = 983791
image_off = 985131
image_off_outline = 987601
image_outline = 985462
image_plus = 985212
image_plus_outline = 990022
image_refresh = 989694
image_refresh_outline = 989695
image_remove = 988184
image_remove_outline = 990024
image_search = 985463
image_search_outline = 985464
image_size_select_actual = 986253
image_size_select_large = 986254
image_size_select_small = 986255
image_sync = 989696
image_sync_outline = 989697
image_text = 988685
import_ = 983802
inbox = 984711
inbox_arrow_down = 983803
inbox_arrow_down_outline = 987760
inbox_arrow_up = 984017
inbox_arrow_up_outline = 987761
inbox_full = 987762
inbox_full_outline = 987763
inbox_multiple = 985264
inbox_multiple_outline = 986024
inbox_outline = 987764
inbox_remove = 988575
inbox_remove_outline = 988576
incognito = 984569
incognito_circle = 988193
incognito_circle_off = 988194
incognito_off = 983157
induction = 989260
infinity = 984804
information = 983804
information_box = 990309
information_box_outline = 990310
information_off = 989068
information_off_outline = 989069
information_outline = 983805
information_slab_box = 990311
information_slab_box_outline = 990312
information_slab_circle = 990313
information_slab_circle_outline = 990314
information_slab_symbol = 990315
information_symbol = 990316
information_variant = 984654
information_variant_box = 990317
information_variant_box_outline = 990318
information_variant_circle = 990319
information_variant_circle_outline = 990320
instagram = 983806
instrument_triangle = 987214
integrated_circuit_chip = 989459
invert_colors = 983809
invert_colors_off = 986698
iobroker = 987880
ip = 985695
ip_network = 985696
ip_network_outline = 986256
ip_outline = 989570
ipod = 986257
iron = 989220
iron_board = 989240
iron_outline = 989221
island = 987215
island_variant = 990406
iv_bag = 987321
jabber = 986581
jeepney = 983810
jellyfish = 986881
jellyfish_outline = 986882
jira = 983811
jquery = 985213
jsfiddle = 983812
jump_rope = 987903
kabaddi = 986503
kangaroo = 988504
karate = 985132
kayaking = 985263
keg = 983813
kettle = 984570
kettle_alert = 987927
kettle_alert_outline = 987928
kettle_off = 987931
kettle_off_outline = 987932
kettle_outline = 986966
kettle_pour_over = 988988
kettle_steam = 987929
kettle_steam_outline = 987930
kettlebell = 987904
key = 983814
key_alert = 989571
key_alert_outline = 989572
key_arrow_right = 987922
key_chain = 988532
key_chain_variant = 988533
key_change = 983815
key_link = 987551
key_minus = 983816
key_outline = 986582
key_plus = 983817
key_remove = 983818
key_star = 987550
key_variant = 983819
key_wireless = 987074
keyboard = 983820
keyboard_backspace = 983821
keyboard_caps = 983822
keyboard_close = 983823
keyboard_close_outline = 990208
keyboard_esc = 987831
keyboard_f1 = 987819
keyboard_f10 = 987828
keyboard_f11 = 987829
keyboard_f12 = 987830
keyboard_f2 = 987820
keyboard_f3 = 987821
keyboard_f4 = 987822
keyboard_f5 = 987823
keyboard_f6 = 987824
keyboard_f7 = 987825
keyboard_f8 = 987826
keyboard_f9 = 987827
keyboard_off = 983824
keyboard_off_outline = 986699
keyboard_outline = 985467
keyboard_return = 983825
keyboard_settings = 985593
keyboard_settings_outline = 985594
keyboard_space = 987216
keyboard_tab = 983826
keyboard_tab_reverse = 983845
keyboard_variant = 983827
khanda = 987389
kickstarter = 984901
kite = 989573
kite_outline = 989574
kitesurfing = 988996
klingon = 987995
knife = 985595
knife_military = 985596
knob = 990102
koala = 988991
kodi = 983828
kubernetes = 987390
label = 983829
label_multiple = 988021
label_multiple_outline = 988022
label_off = 985803
label_off_outline = 985804
label_outline = 983830
label_percent = 987882
label_percent_outline = 987883
label_variant = 985805
label_variant_outline = 985806
ladder = 988578
ladybug = 985133
lambda_ = 984615
lamp = 984757
lamp_outline = 989136
lamps = 988534
lamps_outline = 989137
lan = 983831
lan_check = 987818
lan_connect = 983832
lan_disconnect = 983833
lan_pending = 983834
land_fields = 989874
land_plots = 989875
land_plots_circle = 989876
land_plots_circle_variant = 989877
land_plots_marker = 990301
land_rows_horizontal = 989878
land_rows_vertical = 989879
landslide = 989768
landslide_outline = 989769
language_c = 984689
language_cpp = 984690
language_csharp = 983835
language_css3 = 983836
language_fortran = 987674
language_go = 985043
language_haskell = 986258
language_html5 = 983837
language_java = 985911
language_javascript = 983838
language_kotlin = 987673
language_lua = 985265
language_markdown = 983892
language_markdown_outline = 986971
language_php = 983839
language_python = 983840
language_r = 985044
language_ruby = 986413
language_ruby_on_rails = 985807
language_rust = 988695
language_swift = 984805
language_typescript = 984806
language_xaml = 984691
laptop = 983842
laptop_account = 989770
laptop_off = 984807
laravel = 985808
laser_pointer = 988292
lasso = 986883
lastpass = 984134
latitude = 986967
launch = 983847
lava_lamp = 985045
layers = 983848
layers_edit = 989330
layers_minus = 986700
layers_off = 983849
layers_off_outline = 985597
layers_outline = 985598
layers_plus = 986701
layers_remove = 986702
layers_search = 987654
layers_search_outline = 987655
layers_triple = 986968
layers_triple_outline = 986969
lead_pencil = 984655
leaf = 983850
leaf_circle = 989445
leaf_circle_outline = 989446
leaf_maple = 986259
leaf_maple_off = 987866
leaf_off = 987865
leak = 986583
leak_off = 986584
lectern = 989936
led_off = 983851
led_on = 983852
led_outline = 983853
led_strip = 985046
led_strip_variant = 987217
led_strip_variant_off = 989771
led_variant_off = 983854
led_variant_on = 983855
led_variant_outline = 983856
leek = 987517
less_than = 985468
less_than_or_equal = 985469
library = 983857
library_outline = 989730
library_shelves = 986025
license = 987075
lifebuoy = 985214
light_flood_down = 989575
light_flood_up = 989576
light_recessed = 989083
light_switch = 985470
light_switch_off = 989732
lightbulb = 983861
lightbulb_alert = 989665
lightbulb_alert_outline = 989666
lightbulb_auto = 989184
lightbulb_auto_outline = 989185
lightbulb_cfl = 987656
lightbulb_cfl_off = 987657
lightbulb_cfl_spiral = 987765
lightbulb_cfl_spiral_off = 987843
lightbulb_fluorescent_tube = 989188
lightbulb_fluorescent_tube_outline = 989189
lightbulb_group = 987731
lightbulb_group_off = 987853
lightbulb_group_off_outline = 987854
lightbulb_group_outline = 987732
lightbulb_multiple = 987733
lightbulb_multiple_off = 987855
lightbulb_multiple_off_outline = 987856
lightbulb_multiple_outline = 987734
lightbulb_night = 989772
lightbulb_night_outline = 989773
lightbulb_off = 986703
lightbulb_off_outline = 986704
lightbulb_on = 984808
lightbulb_on_10 = 989774
lightbulb_on_20 = 989775
lightbulb_on_30 = 989776
lightbulb_on_40 = 989777
lightbulb_on_50 = 989778
lightbulb_on_60 = 989779
lightbulb_on_70 = 989780
lightbulb_on_80 = 989781
lightbulb_on_90 = 989782
lightbulb_on_outline = 984809
lightbulb_outline = 983862
lightbulb_question = 989667
lightbulb_question_outline = 989668
lightbulb_spot = 989172
lightbulb_spot_off = 989173
lightbulb_variant = 989186
lightbulb_variant_outline = 989187
lighthouse = 985599
lighthouse_on = 985600
lightning_bolt = 988171
lightning_bolt_circle = 985120
lightning_bolt_outline = 988172
line_scan = 984612
lingerie = 988278
link = 983863
link_box = 986394
link_box_outline = 986395
link_box_variant = 986396
link_box_variant_outline = 986397
link_circle = 990380
link_circle_outline = 990381
link_edit = 990382
link_lock = 987322
link_off = 983864
link_plus = 986260
link_variant = 983865
link_variant_minus = 987391
link_variant_off = 983866
link_variant_plus = 987392
link_variant_remove = 987393
linkedin = 983867
linux = 983869
linux_mint = 985325
lipstick = 988085
liquid_spot = 989222
liquor = 989470
list_box = 990075
list_box_outline = 990076
list_status = 988587
litecoin = 985697
loading = 984946
location_enter = 987076
location_exit = 987077
lock = 983870
lock_alert = 985326
lock_alert_outline = 988625
lock_check = 988058
lock_check_outline = 988840
lock_clock = 985471
lock_minus = 988841
lock_minus_outline = 988842
lock_off = 988785
lock_off_outline = 988786
lock_open = 983871
lock_open_alert = 988059
lock_open_alert_outline = 988626
lock_open_check = 988060
lock_open_check_outline = 988843
lock_open_minus = 988844
lock_open_minus_outline = 988845
lock_open_outline = 983872
lock_open_plus = 988846
lock_open_plus_outline = 988847
lock_open_remove = 988848
lock_open_remove_outline = 988849
lock_open_variant = 987078
lock_open_variant_outline = 987079
lock_outline = 983873
lock_pattern = 984810
lock_percent = 990226
lock_percent_open = 990227
lock_percent_open_outline = 990228
lock_percent_open_variant = 990229
lock_percent_open_variant_outline = 990230
lock_percent_outline = 990231
lock_plus = 984571
lock_plus_outline = 988850
lock_question = 985327
lock_remove = 988851
lock_remove_outline = 988852
lock_reset = 984947
lock_smart = 985266
locker = 985047
locker_multiple = 985048
login = 983874
login_variant = 984572
logout = 983875
logout_variant = 984573
longitude = 986970
looks = 983876
lotion = 988546
lotion_outline = 988547
lotion_plus = 988548
lotion_plus_outline = 988549
loupe = 983877
lumx = 983878
lungs = 987268
mace = 989251
magazine_pistol = 983844
magazine_rifle = 983843
magic_staff = 989252
magnet = 983879
magnet_on = 983880
magnify = 983881
magnify_close = 985472
magnify_expand = 989300
magnify_minus = 983882
magnify_minus_cursor = 985698
magnify_minus_outline = 984812
magnify_plus = 983883
magnify_plus_cursor = 985699
magnify_plus_outline = 984813
magnify_remove_cursor = 987660
magnify_remove_outline = 987661
magnify_scan = 987766
mail = 986811
mailbox = 984814
mailbox_open = 986504
mailbox_open_outline = 986505
mailbox_open_up = 986506
mailbox_open_up_outline = 986507
mailbox_outline = 986508
mailbox_up = 986509
mailbox_up_outline = 986510
manjaro = 988682
map = 983885
map_check = 986812
map_check_outline = 986813
map_clock = 986398
map_clock_outline = 986399
map_legend = 985601
map_marker = 983886
map_marker_account = 989411
map_marker_account_outline = 989412
map_marker_alert = 986885
map_marker_alert_outline = 986886
map_marker_check = 986261
map_marker_check_outline = 987899
map_marker_circle = 983887
map_marker_distance = 985328
map_marker_down = 987394
map_marker_left = 987867
map_marker_left_outline = 987869
map_marker_minus = 984656
map_marker_minus_outline = 987897
map_marker_multiple = 983888
map_marker_multiple_outline = 987767
map_marker_off = 983889
map_marker_off_outline = 987901
map_marker_outline = 985049
map_marker_path = 986400
map_marker_plus = 984657
map_marker_plus_outline = 987896
map_marker_question = 986887
map_marker_question_outline = 986888
map_marker_radius = 983890
map_marker_radius_outline = 987900
map_marker_remove = 986889
map_marker_remove_outline = 987898
map_marker_remove_variant = 986890
map_marker_right = 987868
map_marker_right_outline = 987870
map_marker_star = 988680
map_marker_star_outline = 988681
map_marker_up = 987395
map_minus = 985473
map_outline = 985474
map_plus = 985475
map_search = 985476
map_search_outline = 985477
mapbox = 986026
margin = 983891
marker = 984658
marker_cancel = 986585
marker_check = 983893
mastodon = 985809
material_design = 985478
material_ui = 983895
math_compass = 983896
math_cos = 986262
math_integral = 987080
math_integral_box = 987081
math_log = 987269
math_norm = 987082
math_norm_box = 987083
math_sin = 986263
math_tan = 986264
matrix = 984616
medal = 985479
medal_outline = 987942
medical_bag = 984815
medical_cotton_swab = 989880
medication = 989972
medication_outline = 989973
meditation = 987515
memory = 983899
memory_arrow_down = 990374
menorah = 989140
menorah_fire = 989141
menu = 983900
menu_close = 990352
menu_down = 983901
menu_down_outline = 984758
menu_left = 983902
menu_left_outline = 985602
menu_open = 986027
menu_right = 983903
menu_right_outline = 985603
menu_swap = 985700
menu_swap_outline = 985701
menu_up = 983904
menu_up_outline = 984759
merge = 986972
message = 983905
message_alert = 983906
message_alert_outline = 985604
message_arrow_left = 987890
message_arrow_left_outline = 987891
message_arrow_right = 987892
message_arrow_right_outline = 987893
message_badge = 989505
message_badge_outline = 989506
message_bookmark = 988588
message_bookmark_outline = 988589
message_bulleted = 984738
message_bulleted_off = 984739
message_check = 990090
message_check_outline = 990091
message_cog = 984817
message_cog_outline = 987506
message_draw = 983907
message_fast = 989644
message_fast_outline = 989645
message_flash = 988585
message_flash_outline = 988586
message_image = 983908
message_image_outline = 987500
message_lock = 987084
message_lock_outline = 987501
message_minus = 987502
message_minus_outline = 987503
message_off = 988749
message_off_outline = 988750
message_outline = 983909
message_plus = 984659
message_plus_outline = 987323
message_processing = 983910
message_processing_outline = 987504
message_question = 988986
message_question_outline = 988987
message_reply = 983911
message_reply_outline = 988989
message_reply_text = 983912
message_reply_text_outline = 988990
message_settings = 984816
message_settings_outline = 987505
message_star = 984730
message_star_outline = 987728
message_text = 983913
message_text_clock = 987507
message_text_clock_outline = 987508
message_text_fast = 989646
message_text_fast_outline = 989647
message_text_lock = 987085
message_text_lock_outline = 987509
message_text_outline = 983914
message_video = 983915
meteor = 984617
meter_electric = 989783
meter_electric_outline = 989784
meter_gas = 989785
meter_gas_outline = 989786
metronome = 985050
metronome_tick = 985051
micro_sd = 985052
microphone = 983916
microphone_message = 984330
microphone_message_off = 984331
microphone_minus = 985267
microphone_off = 983917
microphone_outline = 983918
microphone_plus = 985268
microphone_question = 989577
microphone_question_outline = 989578
microphone_settings = 983919
microphone_variant = 983920
microphone_variant_off = 983921
microscope = 984660
microsoft = 983922
microsoft_access = 988046
microsoft_azure = 985093
microsoft_azure_devops = 987093
microsoft_bing = 983204
microsoft_dynamics_365 = 985480
microsoft_edge = 983529
microsoft_excel = 988047
microsoft_internet_explorer = 983808
microsoft_office = 984006
microsoft_onedrive = 984010
microsoft_onenote = 984903
microsoft_outlook = 986402
microsoft_powerpoint = 988048
microsoft_sharepoint = 988049
microsoft_teams = 983739
microsoft_visual_studio = 984592
microsoft_visual_studio_code = 985630
microsoft_windows = 984499
microsoft_windows_classic = 985633
microsoft_word = 988050
microsoft_xbox = 984505
microsoft_xbox_controller = 984506
microsoft_xbox_controller_battery_alert = 984907
microsoft_xbox_controller_battery_charging = 985634
microsoft_xbox_controller_battery_empty = 984908
microsoft_xbox_controller_battery_full = 984909
microsoft_xbox_controller_battery_low = 984910
microsoft_xbox_controller_battery_medium = 984911
microsoft_xbox_controller_battery_unknown = 984912
microsoft_xbox_controller_menu = 986735
microsoft_xbox_controller_off = 984507
microsoft_xbox_controller_view = 986736
microwave = 986265
microwave_off = 988195
middleware = 986973
middleware_outline = 986974
midi = 985329
midi_port = 985330
mine = 986586
minecraft = 983923
mini_sd = 985605
minidisc = 985606
minus = 983924
minus_box = 983925
minus_box_multiple = 987457
minus_box_multiple_outline = 987458
minus_box_outline = 984818
minus_circle = 983926
minus_circle_multiple = 983898
minus_circle_multiple_outline = 985811
minus_circle_off = 988249
minus_circle_off_outline = 988250
minus_circle_outline = 983927
minus_network = 983928
minus_network_outline = 986266
minus_thick = 988729
mirror = 987645
mirror_rectangle = 989087
mirror_variant = 989088
mixed_martial_arts = 986511
mixed_reality = 985215
molecule = 986028
molecule_co = 987902
molecule_co2 = 985060
monitor = 983929
monitor_account = 989787
monitor_arrow_down = 989648
monitor_arrow_down_variant = 989649
monitor_cellphone = 985481
monitor_cellphone_star = 985482
monitor_dashboard = 985607
monitor_edit = 987846
monitor_eye = 988084
monitor_lock = 986587
monitor_multiple = 983930
monitor_off = 986512
monitor_screenshot = 986705
monitor_share = 988291
monitor_shimmer = 987396
monitor_small = 989302
monitor_speaker = 986975
monitor_speaker_off = 986976
monitor_star = 986588
monitor_vertical = 990259
moon_first_quarter = 986977
moon_full = 986978
moon_last_quarter = 986979
moon_new = 986980
moon_waning_crescent = 986981
moon_waning_gibbous = 986982
moon_waxing_crescent = 986983
moon_waxing_gibbous = 986984
moped = 987270
moped_electric = 988599
moped_electric_outline = 988600
moped_outline = 988601
more = 983931
mortar_pestle = 989000
mortar_pestle_plus = 984049
mosque = 986437
mosque_outline = 989223
mother_heart = 987924
mother_nurse = 986401
motion = 988594
motion_outline = 988595
motion_pause = 988560
motion_pause_outline = 988562
motion_play = 988559
motion_play_outline = 988561
motion_sensor = 986513
motion_sensor_off = 988213
motorbike = 983932
motorbike_electric = 988602
motorbike_off = 989974
mouse = 983933
mouse_bluetooth = 985483
mouse_move_down = 988496
mouse_move_up = 988497
mouse_move_vertical = 988498
mouse_off = 983934
mouse_variant = 983935
mouse_variant_off = 983936
move_resize = 984661
move_resize_variant = 984662
movie = 983937
movie_check = 988915
movie_check_outline = 988916
movie_cog = 988917
movie_cog_outline = 988918
movie_edit = 987426
movie_edit_outline = 987427
movie_filter = 987428
movie_filter_outline = 987429
movie_minus = 988919
movie_minus_outline = 988920
movie_off = 988921
movie_off_outline = 988922
movie_open = 987086
movie_open_check = 988923
movie_open_check_outline = 988924
movie_open_cog = 988925
movie_open_cog_outline = 988926
movie_open_edit = 988927
movie_open_edit_outline = 988928
movie_open_minus = 988929
movie_open_minus_outline = 988930
movie_open_off = 988931
movie_open_off_outline = 988932
movie_open_outline = 987087
movie_open_play = 988933
movie_open_play_outline = 988934
movie_open_plus = 988935
movie_open_plus_outline = 988936
movie_open_remove = 988937
movie_open_remove_outline = 988938
movie_open_settings = 988939
movie_open_settings_outline = 988940
movie_open_star = 988941
movie_open_star_outline = 988942
movie_outline = 986589
movie_play = 988943
movie_play_outline = 988944
movie_plus = 988945
movie_plus_outline = 988946
movie_remove = 988947
movie_remove_outline = 988948
movie_roll = 985054
movie_search = 987602
movie_search_outline = 987603
movie_settings = 988949
movie_settings_outline = 988950
movie_star = 988951
movie_star_outline = 988952
mower = 988783
mower_bag = 988784
mower_bag_on = 990048
mower_on = 990047
muffin = 985484
multicast = 989331
multimedia = 990103
multiplication = 983938
multiplication_box = 983939
mushroom = 985055
mushroom_off = 988154
mushroom_off_outline = 988155
mushroom_outline = 985056
music = 984922
music_accidental_double_flat = 986985
music_accidental_double_sharp = 986986
music_accidental_flat = 986987
music_accidental_natural = 986988
music_accidental_sharp = 986989
music_box = 983940
music_box_multiple = 983859
music_box_multiple_outline = 986884
music_box_outline = 983941
music_circle = 983942
music_circle_outline = 985812
music_clef_alto = 986990
music_clef_bass = 986991
music_clef_treble = 986992
music_note = 983943
music_note_bluetooth = 984574
music_note_bluetooth_off = 984575
music_note_eighth = 983944
music_note_eighth_dotted = 986993
music_note_half = 983945
music_note_half_dotted = 986994
music_note_minus = 990089
music_note_off = 983946
music_note_off_outline = 986995
music_note_outline = 986996
music_note_plus = 986590
music_note_quarter = 983947
music_note_quarter_dotted = 986997
music_note_sixteenth = 983948
music_note_sixteenth_dotted = 986998
music_note_whole = 983949
music_note_whole_dotted = 986999
music_off = 984923
music_rest_eighth = 987000
music_rest_half = 987001
music_rest_quarter = 987002
music_rest_sixteenth = 987003
music_rest_whole = 987004
mustache = 988638
nail = 986591
nas = 985331
nativescript = 985216
nature = 983950
nature_outline = 990321
nature_people = 983951
nature_people_outline = 990322
navigation = 983952
navigation_outline = 988679
navigation_variant = 989424
navigation_variant_outline = 989425
near_me = 984525
necklace = 986891
needle = 983953
needle_off = 989650
netflix = 984902
network = 984819
network_off = 986267
network_off_outline = 986268
network_outline = 986269
network_pos = 989899
network_strength_1 = 985332
network_strength_1_alert = 985333
network_strength_2 = 985334
network_strength_2_alert = 985335
network_strength_3 = 985336
network_strength_3_alert = 985337
network_strength_4 = 985338
network_strength_4_alert = 985339
network_strength_4_cog = 989466
network_strength_off = 985340
network_strength_off_outline = 985341
network_strength_outline = 985342
new_box = 983956
newspaper = 983957
newspaper_check = 989507
newspaper_minus = 986892
newspaper_plus = 986893
newspaper_remove = 989508
newspaper_variant = 987137
newspaper_variant_multiple = 987138
newspaper_variant_multiple_outline = 987139
newspaper_variant_outline = 987140
nfc = 983958
nfc_search_variant = 986707
nfc_tap = 983959
nfc_variant = 983960
nfc_variant_off = 986708
ninja = 984948
nintendo_game_boy = 988051
nintendo_switch = 985057
nintendo_wii = 984491
nintendo_wiiu = 984877
nix = 987397
nodejs = 983961
noodles = 987518
not_equal = 985485
not_equal_variant = 985486
note = 983962
note_alert = 989053
note_alert_outline = 989054
note_check = 989055
note_check_outline = 989056
note_edit = 989057
note_edit_outline = 989058
note_minus = 988751
note_minus_outline = 988752
note_multiple = 984760
note_multiple_outline = 984761
note_off = 989059
note_off_outline = 989060
note_outline = 983963
note_plus = 983964
note_plus_outline = 983965
note_remove = 988753
note_remove_outline = 988754
note_search = 988755
note_search_outline = 988756
note_text = 983966
note_text_outline = 987607
notebook = 985134
notebook_check = 988405
notebook_check_outline = 988406
notebook_edit = 988391
notebook_edit_outline = 988393
notebook_heart = 989707
notebook_heart_outline = 989708
notebook_minus = 988688
notebook_minus_outline = 988689
notebook_multiple = 986709
notebook_outline = 986815
notebook_plus = 988690
notebook_plus_outline = 988691
notebook_remove = 988692
notebook_remove_outline = 988693
notification_clear_all = 983967
npm = 984823
nuke = 984740
null = 985058
numeric = 983968
numeric_0 = 985913
numeric_0_box = 983969
numeric_0_box_multiple = 986894
numeric_0_box_multiple_outline = 983970
numeric_0_box_outline = 983971
numeric_0_circle = 986270
numeric_0_circle_outline = 986271
numeric_1 = 985914
numeric_1_box = 983972
numeric_1_box_multiple = 986895
numeric_1_box_multiple_outline = 983973
numeric_1_box_outline = 983974
numeric_1_circle = 986272
numeric_1_circle_outline = 986273
numeric_10 = 987113
numeric_10_box = 987005
numeric_10_box_multiple = 987114
numeric_10_box_multiple_outline = 987115
numeric_10_box_outline = 987006
numeric_10_circle = 987116
numeric_10_circle_outline = 987117
numeric_2 = 985915
numeric_2_box = 983975
numeric_2_box_multiple = 986896
numeric_2_box_multiple_outline = 983976
numeric_2_box_outline = 983977
numeric_2_circle = 986274
numeric_2_circle_outline = 986275
numeric_3 = 985916
numeric_3_box = 983978
numeric_3_box_multiple = 986897
numeric_3_box_multiple_outline = 983979
numeric_3_box_outline = 983980
numeric_3_circle = 986276
numeric_3_circle_outline = 986277
numeric_4 = 985917
numeric_4_box = 983981
numeric_4_box_multiple = 986898
numeric_4_box_multiple_outline = 983986
numeric_4_box_outline = 983982
numeric_4_circle = 986278
numeric_4_circle_outline = 986279
numeric_5 = 985918
numeric_5_box = 983985
numeric_5_box_multiple = 986899
numeric_5_box_multiple_outline = 983983
numeric_5_box_outline = 983984
numeric_5_circle = 986280
numeric_5_circle_outline = 986281
numeric_6 = 985919
numeric_6_box = 983987
numeric_6_box_multiple = 986900
numeric_6_box_multiple_outline = 983988
numeric_6_box_outline = 983989
numeric_6_circle = 986282
numeric_6_circle_outline = 986283
numeric_7 = 985920
numeric_7_box = 983990
numeric_7_box_multiple = 986901
numeric_7_box_multiple_outline = 983991
numeric_7_box_outline = 983992
numeric_7_circle = 986284
numeric_7_circle_outline = 986285
numeric_8 = 985921
numeric_8_box = 983993
numeric_8_box_multiple = 986902
numeric_8_box_multiple_outline = 983994
numeric_8_box_outline = 983995
numeric_8_circle = 986286
numeric_8_circle_outline = 986287
numeric_9 = 985922
numeric_9_box = 983996
numeric_9_box_multiple = 986903
numeric_9_box_multiple_outline = 983997
numeric_9_box_outline = 983998
numeric_9_circle = 986288
numeric_9_circle_outline = 986289
numeric_9_plus = 987118
numeric_9_plus_box = 983999
numeric_9_plus_box_multiple = 986904
numeric_9_plus_box_multiple_outline = 984000
numeric_9_plus_box_outline = 984001
numeric_9_plus_circle = 986290
numeric_9_plus_circle_outline = 986291
numeric_negative_1 = 987218
numeric_off = 989651
numeric_positive_1 = 988619
nut = 984824
nutrition = 984002
nuxt = 987398
oar = 984700
ocarina = 986592
oci = 987881
ocr = 987450
octagon = 984003
octagon_outline = 984004
octagram = 984825
octagram_edit = 990260
octagram_edit_outline = 990261
octagram_minus = 990262
octagram_minus_outline = 990263
octagram_outline = 984949
octagram_plus = 990264
octagram_plus_outline = 990265
octahedron = 989520
octahedron_off = 989521
odnoklassniki = 984005
offer = 987675
office_building = 985489
office_building_cog = 989513
office_building_cog_outline = 989514
office_building_marker = 988448
office_building_marker_outline = 988449
office_building_minus = 990122
office_building_minus_outline = 990123
office_building_outline = 988447
office_building_plus = 990120
office_building_plus_outline = 990121
office_building_remove = 990124
office_building_remove_outline = 990125
oil = 984007
oil_lamp = 986905
oil_level = 987219
oil_temperature = 987128
om = 985459
omega = 984009
one_up = 986029
onepassword = 985217
opacity = 984524
open_in_app = 984011
open_in_new = 984012
open_source_initiative = 986030
openid = 984013
opera = 984014
orbit = 983064
orbit_variant = 988635
order_alphabetical_ascending = 983565
order_alphabetical_descending = 986375
order_bool_ascending = 983742
order_bool_ascending_variant = 985487
order_bool_descending = 988036
order_bool_descending_variant = 985488
order_numeric_ascending = 984389
order_numeric_descending = 984390
origin = 985923
ornament = 984015
ornament_variant = 984016
outdoor_lamp = 987220
overscan = 987141
owl = 984018
pac_man = 986031
package = 984019
package_check = 990033
package_down = 984020
package_up = 984021
package_variant = 984022
package_variant_closed = 984023
package_variant_closed_check = 990034
package_variant_closed_minus = 989652
package_variant_closed_plus = 989653
package_variant_closed_remove = 989654
package_variant_minus = 989655
package_variant_plus = 989656
package_variant_remove = 989657
page_first = 984576
page_last = 984577
page_layout_body = 984826
page_layout_footer = 984827
page_layout_header = 984828
page_layout_header_footer = 987007
page_layout_sidebar_left = 984829
page_layout_sidebar_right = 984830
page_next = 986032
page_next_outline = 986033
page_previous = 986034
page_previous_outline = 986035
pail = 988183
pail_minus = 988215
pail_minus_outline = 988220
pail_off = 988217
pail_off_outline = 988222
pail_outline = 988218
pail_plus = 988214
pail_plus_outline = 988219
pail_remove = 988216
pail_remove_outline = 988221
palette = 984024
palette_advanced = 984025
palette_outline = 986636
palette_swatch = 985269
palette_swatch_outline = 987996
palette_swatch_variant = 989530
palm_tree = 987221
pan = 986036
pan_bottom_left = 986037
pan_bottom_right = 986038
pan_down = 986039
pan_horizontal = 986040
pan_left = 986041
pan_right = 986042
pan_top_left = 986043
pan_top_right = 986044
pan_up = 986045
pan_vertical = 986046
panda = 984026
pandora = 984027
panorama = 984028
panorama_fisheye = 984029
panorama_horizontal = 989480
panorama_horizontal_outline = 984030
panorama_outline = 989580
panorama_sphere = 989581
panorama_sphere_outline = 989582
panorama_variant = 989583
panorama_variant_outline = 989584
panorama_vertical = 989481
panorama_vertical_outline = 984031
panorama_wide_angle = 989535
panorama_wide_angle_outline = 984032
paper_cut_vertical = 984033
paper_roll = 987479
paper_roll_outline = 987480
paperclip = 984034
paperclip_check = 989894
paperclip_lock = 989658
paperclip_minus = 989895
paperclip_off = 989896
paperclip_plus = 989897
paperclip_remove = 989898
parachute = 986292
parachute_outline = 986293
paragliding = 988997
parking = 984035
party_popper = 987222
passport = 985059
passport_alert = 990392
passport_biometric = 986593
passport_cancel = 990393
passport_check = 990394
passport_minus = 990395
passport_plus = 990396
passport_remove = 990397
pasta = 987488
patio_heater = 987008
patreon = 985218
pause = 984036
pause_box = 983228
pause_box_outline = 990074
pause_circle = 984037
pause_circle_outline = 984038
pause_octagon = 984039
pause_octagon_outline = 984040
paw = 984041
paw_off = 984663
paw_off_outline = 988790
paw_outline = 988789
peace = 985220
peanut = 987132
peanut_off = 987133
peanut_off_outline = 987135
peanut_outline = 987134
pen = 984042
pen_lock = 986594
pen_minus = 986595
pen_off = 986596
pen_plus = 986597
pen_remove = 986598
pencil = 984043
pencil_box = 984044
pencil_box_multiple = 987460
pencil_box_multiple_outline = 987461
pencil_box_outline = 984045
pencil_circle = 984831
pencil_circle_outline = 984950
pencil_lock = 984046
pencil_lock_outline = 986599
pencil_minus = 986600
pencil_minus_outline = 986601
pencil_off = 984047
pencil_off_outline = 986602
pencil_outline = 986294
pencil_plus = 986603
pencil_plus_outline = 986604
pencil_remove = 986605
pencil_remove_outline = 986606
pencil_ruler = 987987
pencil_ruler_outline = 990225
penguin = 986816
pentagon = 984833
pentagon_outline = 984832
pentagram = 988775
percent = 984048
percent_box = 989698
percent_box_outline = 989699
percent_circle = 989700
percent_circle_outline = 989701
percent_outline = 987768
periodic_table = 985270
perspective_less = 986403
perspective_more = 986404
ph = 989125
phone = 984050
phone_alert = 986906
phone_alert_outline = 987534
phone_bluetooth = 984051
phone_bluetooth_outline = 987535
phone_cancel = 987324
phone_cancel_outline = 987536
phone_check = 987561
phone_check_outline = 987562
phone_classic = 984578
phone_classic_off = 987769
phone_clock = 989659
phone_dial = 988505
phone_dial_outline = 988506
phone_forward = 984052
phone_forward_outline = 987537
phone_hangup = 984053
phone_hangup_outline = 987538
phone_in_talk = 984054
phone_in_talk_outline = 987522
phone_incoming = 984055
phone_incoming_outgoing = 990015
phone_incoming_outgoing_outline = 990016
phone_incoming_outline = 987539
phone_lock = 984056
phone_lock_outline = 987540
phone_log = 984057
phone_log_outline = 987541
phone_message = 987542
phone_message_outline = 987543
phone_minus = 984664
phone_minus_outline = 987544
phone_missed = 984058
phone_missed_outline = 987557
phone_off = 986607
phone_off_outline = 987558
phone_outgoing = 984059
phone_outgoing_outline = 987545
phone_outline = 986608
phone_paused = 984060
phone_paused_outline = 987546
phone_plus = 984665
phone_plus_outline = 987547
phone_refresh = 989587
phone_refresh_outline = 989588
phone_remove = 988463
phone_remove_outline = 988464
phone_return = 985135
phone_return_outline = 987548
phone_ring = 987563
phone_ring_outline = 987564
phone_rotate_landscape = 985221
phone_rotate_portrait = 985222
phone_settings = 984061
phone_settings_outline = 987549
phone_sync = 989589
phone_sync_outline = 989590
phone_voip = 984062
pi = 984063
pi_box = 984064
pi_hole = 986609
piano = 984701
piano_off = 984728
pickaxe = 985271
picture_in_picture_bottom_right = 986711
picture_in_picture_bottom_right_outline = 986712
picture_in_picture_top_right = 986713
picture_in_picture_top_right_outline = 986714
pier = 985223
pier_crane = 985224
pig = 984065
pig_variant = 987142
pig_variant_outline = 988792
piggy_bank = 987143
piggy_bank_outline = 988793
pill = 984066
pill_multiple = 990028
pill_off = 989788
pillar = 984834
pin = 984067
pin_off = 984068
pin_off_outline = 985392
pin_outline = 985393
pine_tree = 984069
pine_tree_box = 984070
pine_tree_fire = 988186
pine_tree_variant = 990323
pine_tree_variant_outline = 990324
pinterest = 984071
pinwheel = 985813
pinwheel_outline = 985814
pipe = 985061
pipe_disconnected = 985062
pipe_leak = 985225
pipe_valve = 989261
pipe_wrench = 987988
pirate = 985608
pistol = 984835
piston = 985226
pitchfork = 988499
pizza = 984073
plane_car = 989951
plane_train = 989952
play = 984074
play_box = 987770
play_box_edit_outline = 990266
play_box_lock = 989718
play_box_lock_open = 989719
play_box_lock_open_outline = 989720
play_box_lock_outline = 989721
play_box_multiple = 986393
play_box_multiple_outline = 988134
play_box_outline = 984075
play_circle = 984076
play_circle_outline = 984077
play_network = 985227
play_network_outline = 986295
play_outline = 986907
play_pause = 984078
play_protected_content = 984079
play_speed = 985343
playlist_check = 984519
playlist_edit = 985344
playlist_minus = 984080
playlist_music = 986296
playlist_music_outline = 986297
playlist_play = 984081
playlist_plus = 984082
playlist_remove = 984083
playlist_star = 986610
plex = 984762
pliers = 989604
plus = 984085
plus_box = 984086
plus_box_multiple = 983860
plus_box_multiple_outline = 987459
plus_box_outline = 984836
plus_circle = 984087
plus_circle_multiple = 983884
plus_circle_multiple_outline = 984088
plus_circle_outline = 984089
plus_lock = 989789
plus_lock_open = 989790
plus_minus = 985490
plus_minus_box = 985491
plus_minus_variant = 988361
plus_network = 984090
plus_network_outline = 986298
plus_outline = 984837
plus_thick = 987628
pocket = 990398
podcast = 985492
podium = 986405
podium_bronze = 986406
podium_gold = 986407
podium_silver = 986408
point_of_sale = 986514
pokeball = 984093
pokemon_go = 985609
poker_chip = 985136
polaroid = 984094
police_badge = 987495
police_badge_outline = 987496
police_station = 989241
poll = 984095
polo = 988355
polymer = 984097
pool = 984582
pool_thermometer = 989791
popcorn = 984098
post = 987144
post_lamp = 989792
post_outline = 987145
postage_stamp = 986299
pot = 983781
pot_mix = 984667
pot_mix_outline = 984695
pot_outline = 983807
pot_steam = 984666
pot_steam_outline = 983846
pound = 984099
pound_box = 984100
pound_box_outline = 987519
power = 984101
power_cycle = 985345
power_off = 985346
power_on = 985347
power_plug = 984741
power_plug_battery = 990267
power_plug_battery_outline = 990268
power_plug_off = 984742
power_plug_off_outline = 988196
power_plug_outline = 988197
power_settings = 984102
power_sleep = 985348
power_socket = 984103
power_socket_au = 985349
power_socket_ch = 987059
power_socket_de = 987399
power_socket_eu = 985063
power_socket_fr = 987400
power_socket_it = 988415
power_socket_jp = 987401
power_socket_uk = 985064
power_socket_us = 985065
power_standby = 985350
powershell = 985610
prescription = 984838
presentation = 984104
presentation_play = 984105
pretzel = 988514
printer = 984106
printer_3d = 984107
printer_3d_nozzle = 986715
printer_3d_nozzle_alert = 987584
printer_3d_nozzle_alert_outline = 987585
printer_3d_nozzle_heat = 989368
printer_3d_nozzle_heat_outline = 989369
printer_3d_nozzle_off = 989977
printer_3d_nozzle_off_outline = 989978
printer_3d_nozzle_outline = 986716
printer_3d_off = 989966
printer_alert = 984108
printer_check = 987462
printer_eye = 988248
printer_off = 986717
printer_off_outline = 989061
printer_outline = 989062
printer_pos = 987223
printer_pos_alert = 990140
printer_pos_alert_outline = 990141
printer_pos_cancel = 990142
printer_pos_cancel_outline = 990143
printer_pos_check = 990144
printer_pos_check_outline = 990145
printer_pos_cog = 990146
printer_pos_cog_outline = 990147
printer_pos_edit = 990148
printer_pos_edit_outline = 990149
printer_pos_minus = 990150
printer_pos_minus_outline = 990151
printer_pos_network = 990152
printer_pos_network_outline = 990153
printer_pos_off = 990154
printer_pos_off_outline = 990155
printer_pos_outline = 990156
printer_pos_pause = 990157
printer_pos_pause_outline = 990158
printer_pos_play = 990159
printer_pos_play_outline = 990160
printer_pos_plus = 990161
printer_pos_plus_outline = 990162
printer_pos_refresh = 990163
printer_pos_refresh_outline = 990164
printer_pos_remove = 990165
printer_pos_remove_outline = 990166
printer_pos_star = 990167
printer_pos_star_outline = 990168
printer_pos_stop = 990169
printer_pos_stop_outline = 990170
printer_pos_sync = 990171
printer_pos_sync_outline = 990172
printer_pos_wrench = 990173
printer_pos_wrench_outline = 990174
printer_search = 988247
printer_settings = 984839
printer_wireless = 985611
priority_high = 984579
priority_low = 984580
professional_hexagon = 984109
progress_alert = 986300
progress_check = 985493
progress_clock = 985494
progress_close = 987402
progress_download = 985495
progress_helper = 990114
progress_pencil = 989063
progress_question = 988450
progress_star = 989064
progress_star_four_points = 990269
progress_upload = 985496
progress_wrench = 986301
projector = 984110
projector_off = 989731
projector_screen = 984111
projector_screen_off = 989197
projector_screen_off_outline = 989198
projector_screen_outline = 988964
projector_screen_variant = 989199
projector_screen_variant_off = 989200
projector_screen_variant_off_outline = 989201
projector_screen_variant_outline = 989202
propane_tank = 987991
propane_tank_outline = 987992
protocol = 987096
publish = 984743
publish_off = 989509
pulse = 984112
pump = 988162
pump_off = 989986
pumpkin = 986047
purse = 986908
purse_outline = 986909
puzzle = 984113
puzzle_check = 988198
puzzle_check_outline = 988199
puzzle_edit = 988371
puzzle_edit_outline = 988377
puzzle_heart = 988372
puzzle_heart_outline = 988378
puzzle_minus = 988369
puzzle_minus_outline = 988375
puzzle_outline = 985702
puzzle_plus = 988368
puzzle_plus_outline = 988374
puzzle_remove = 988370
puzzle_remove_outline = 988376
puzzle_star = 988373
puzzle_star_outline = 988379
pyramid = 989522
pyramid_off = 989523
qi = 985497
qqchat = 984581
qrcode = 984114
qrcode_edit = 985272
qrcode_minus = 987532
qrcode_plus = 987531
qrcode_remove = 987533
qrcode_scan = 984115
quadcopter = 984116
quality_high = 984117
quality_low = 985612
quality_medium = 985613
queue_first_in_last_out = 990383
quora = 986409
rabbit = 985351
rabbit_variant = 989793
rabbit_variant_outline = 989794
racing_helmet = 986515
racquetball = 986516
radar = 984119
radiator = 984120
radiator_disabled = 985815
radiator_off = 985816
radio = 984121
radio_am = 986302
radio_fm = 986303
radio_handheld = 984122
radio_off = 987676
radio_tower = 984123
radioactive = 984124
radioactive_circle = 989277
radioactive_circle_outline = 989278
radioactive_off = 986817
radiobox_blank = 984125
radiobox_indeterminate_variant = 990302
radiobox_marked = 984126
radiology_box = 988357
radiology_box_outline = 988358
radius = 986304
radius_outline = 986305
railroad_light = 986910
rake = 988484
raspberry_pi = 984127
raw = 989711
raw_off = 989712
ray_end = 984128
ray_end_arrow = 984129
ray_start = 984130
ray_start_arrow = 984131
ray_start_end = 984132
ray_start_vertex_end = 988632
ray_vertex = 984133
razor_double_edge = 989591
razor_single_edge = 989592
react = 984840
read = 984135
receipt = 985124
receipt_clock = 990270
receipt_clock_outline = 990271
receipt_outline = 984311
receipt_send = 990272
receipt_send_outline = 990273
receipt_text = 984137
receipt_text_arrow_left = 990274
receipt_text_arrow_left_outline = 990275
receipt_text_arrow_right = 990276
receipt_text_arrow_right_outline = 990277
receipt_text_check = 989795
receipt_text_check_outline = 989796
receipt_text_clock = 990278
receipt_text_clock_outline = 990279
receipt_text_edit = 990280
receipt_text_edit_outline = 990281
receipt_text_minus = 989797
receipt_text_minus_outline = 989798
receipt_text_outline = 989660
receipt_text_plus = 989799
receipt_text_plus_outline = 989800
receipt_text_remove = 989801
receipt_text_remove_outline = 989802
receipt_text_send = 990282
receipt_text_send_outline = 990283
record = 984138
record_circle = 986818
record_circle_outline = 986819
record_player = 985498
record_rec = 984139
rectangle = 986718
rectangle_outline = 986719
recycle = 984140
recycle_variant = 988061
reddit = 984141
redhat = 987419
redo = 984142
redo_variant = 984143
reflect_horizontal = 985614
reflect_vertical = 985615
refresh = 984144
refresh_auto = 989426
refresh_circle = 988023
regex = 984145
registered_trademark = 985703
reiterate = 988552
relation_many_to_many = 988310
relation_many_to_one = 988311
relation_many_to_one_or_many = 988312
relation_many_to_only_one = 988313
relation_many_to_zero_or_many = 988314
relation_many_to_zero_or_one = 988315
relation_one_or_many_to_many = 988316
relation_one_or_many_to_one = 988317
relation_one_or_many_to_one_or_many = 988318
relation_one_or_many_to_only_one = 988319
relation_one_or_many_to_zero_or_many = 988320
relation_one_or_many_to_zero_or_one = 988321
relation_one_to_many = 988322
relation_one_to_one = 988323
relation_one_to_one_or_many = 988324
relation_one_to_only_one = 988325
relation_one_to_zero_or_many = 988326
relation_one_to_zero_or_one = 988327
relation_only_one_to_many = 988328
relation_only_one_to_one = 988329
relation_only_one_to_one_or_many = 988330
relation_only_one_to_only_one = 988331
relation_only_one_to_zero_or_many = 988332
relation_only_one_to_zero_or_one = 988333
relation_zero_or_many_to_many = 988334
relation_zero_or_many_to_one = 988335
relation_zero_or_many_to_one_or_many = 988336
relation_zero_or_many_to_only_one = 988337
relation_zero_or_many_to_zero_or_many = 988338
relation_zero_or_many_to_zero_or_one = 988339
relation_zero_or_one_to_many = 988340
relation_zero_or_one_to_one = 988341
relation_zero_or_one_to_one_or_many = 988342
relation_zero_or_one_to_only_one = 988343
relation_zero_or_one_to_zero_or_many = 988344
relation_zero_or_one_to_zero_or_one = 988345
relative_scale = 984146
reload = 984147
reload_alert = 987403
reminder = 985228
remote = 984148
remote_desktop = 985273
remote_off = 986820
remote_tv = 986821
remote_tv_off = 986822
rename = 990232
rename_box = 984149
rename_box_outline = 990233
rename_outline = 990234
reorder_horizontal = 984712
reorder_vertical = 984713
repeat = 984150
repeat_off = 984151
repeat_once = 984152
repeat_variant = 984391
replay = 984153
reply = 984154
reply_all = 984155
reply_all_outline = 986911
reply_circle = 987566
reply_outline = 986912
reproduction = 984156
resistor = 985924
resistor_nodes = 985925
resize = 985704
resize_bottom_right = 984157
responsive = 984158
restart = 984841
restart_alert = 987404
restart_off = 986517
restore = 985499
restore_alert = 987405
rewind = 984159
rewind_10 = 986410
rewind_15 = 989510
rewind_30 = 986518
rewind_45 = 989971
rewind_5 = 987641
rewind_60 = 988684
rewind_outline = 984842
rhombus = 984843
rhombus_medium = 985616
rhombus_medium_outline = 988380
rhombus_outline = 984844
rhombus_split = 985617
rhombus_split_outline = 988381
ribbon = 984160
rice = 985066
rickshaw = 988603
rickshaw_electric = 988604
ring = 985067
rivet = 986720
road = 984161
road_variant = 984162
robber = 987224
robot = 984745
robot_angry = 988829
robot_angry_outline = 988830
robot_confused = 988831
robot_confused_outline = 988832
robot_dead = 988833
robot_dead_outline = 988834
robot_excited = 988835
robot_excited_outline = 988836
robot_happy = 988953
robot_happy_outline = 988954
robot_industrial = 985926
robot_industrial_outline = 989722
robot_love = 988837
robot_love_outline = 988838
robot_mower = 987639
robot_mower_outline = 987635
robot_off = 988839
robot_off_outline = 988795
robot_outline = 988794
robot_vacuum = 984845
robot_vacuum_alert = 990045
robot_vacuum_off = 990209
robot_vacuum_variant = 985352
robot_vacuum_variant_alert = 990046
robot_vacuum_variant_off = 990210
rocket = 984163
rocket_launch = 988382
rocket_launch_outline = 988383
rocket_outline = 988079
rodent = 987943
roller_shade = 989803
roller_shade_closed = 989804
roller_skate = 986411
roller_skate_off = 983365
rollerblade = 986412
rollerblade_off = 983086
rollupjs = 986048
rolodex = 989881
rolodex_outline = 989882
roman_numeral_1 = 987272
roman_numeral_10 = 987281
roman_numeral_2 = 987273
roman_numeral_3 = 987274
roman_numeral_4 = 987275
roman_numeral_5 = 987276
roman_numeral_6 = 987277
roman_numeral_7 = 987278
roman_numeral_8 = 987279
roman_numeral_9 = 987280
room_service = 985229
room_service_outline = 986519
rotate_360 = 989593
rotate_3d = 986823
rotate_3d_variant = 984164
rotate_left = 984165
rotate_left_variant = 984166
rotate_orbit = 986520
rotate_right = 984167
rotate_right_variant = 984168
rounded_corner = 984583
router = 987618
router_network = 987271
router_network_wireless = 990359
router_wireless = 984169
router_wireless_off = 988579
router_wireless_settings = 985705
routes = 984170
routes_clock = 987225
rowing = 984584
rss = 984171
rss_box = 984172
rss_off = 986913
rug = 988277
rugby = 986521
ruler = 984173
ruler_square = 986306
ruler_square_compass = 986814
run = 984846
run_fast = 984174
rv_truck = 987604
sack = 986414
sack_outline = 990284
sack_percent = 986415
safe = 985706
safe_square = 987772
safe_square_outline = 987773
safety_goggles = 986416
sail_boat = 986824
sail_boat_sink = 989935
sale = 984175
sale_outline = 989702
salesforce = 985230
sass = 985068
satellite = 984176
satellite_uplink = 985353
satellite_variant = 984177
sausage = 985274
sausage_off = 989065
saw_blade = 986721
sawtooth_wave = 988282
saxophone = 984585
scale = 984178
scale_balance = 984529
scale_bathroom = 984179
scale_off = 987226
scale_unbalanced = 989624
scan_helper = 988120
scanner = 984747
scanner_off = 985354
scatter_plot = 986825
scatter_plot_outline = 986826
scent = 989528
scent_off = 989529
school = 984180
school_outline = 987520
scissors_cutting = 985707
scooter = 988605
scooter_electric = 988606
scoreboard = 987774
scoreboard_outline = 987775
screen_rotation = 984181
screen_rotation_lock = 984184
screw_flat_top = 986611
screw_lag = 986612
screw_machine_flat_top = 986613
screw_machine_round_top = 986614
screw_round_top = 986615
screwdriver = 984182
script = 986049
script_outline = 984183
script_text = 986050
script_text_key = 988965
script_text_key_outline = 988966
script_text_outline = 986051
script_text_play = 988967
script_text_play_outline = 988968
sd = 984185
seal = 984186
seal_variant = 987097
search_web = 984847
seat = 986307
seat_flat = 984187
seat_flat_angled = 984188
seat_individual_suite = 984189
seat_legroom_extra = 984190
seat_legroom_normal = 984191
seat_legroom_reduced = 984192
seat_outline = 986308
seat_passenger = 987721
seat_recline_extra = 984193
seat_recline_normal = 984194
seatbelt = 986309
security = 984195
security_network = 984196
seed = 986722
seed_off = 988157
seed_off_outline = 988158
seed_outline = 986723
seed_plus = 989805
seed_plus_outline = 989806
seesaw = 988580
segment = 986827
select = 984197
select_all = 984198
select_arrow_down = 990041
select_arrow_up = 990040
select_color = 986417
select_compare = 985817
select_drag = 985708
select_group = 987010
select_inverse = 984199
select_marker = 987776
select_multiple = 987777
select_multiple_marker = 987778
select_off = 984200
select_place = 987098
select_remove = 989121
select_search = 987652
selection = 984201
selection_drag = 985709
selection_ellipse = 986418
selection_ellipse_arrow_inside = 986914
selection_ellipse_remove = 989122
selection_marker = 987779
selection_multiple = 987781
selection_multiple_marker = 987780
selection_off = 984951
selection_remove = 989123
selection_search = 987653
semantic_web = 987926
send = 984202
send_check = 987489
send_check_outline = 987490
send_circle = 986616
send_circle_outline = 986617
send_clock = 987491
send_clock_outline = 987492
send_lock = 985069
send_lock_outline = 987494
send_outline = 987493
send_variant = 990285
send_variant_clock = 990334
send_variant_clock_outline = 990335
send_variant_outline = 990286
serial_port = 984668
server = 984203
server_minus = 984204
server_minus_outline = 990360
server_network = 984205
server_network_off = 984206
server_network_outline = 990361
server_off = 984207
server_outline = 990362
server_plus = 984208
server_plus_outline = 990363
server_remove = 984209
server_security = 984210
set_all = 984952
set_center = 984953
set_center_right = 984954
set_left = 984955
set_left_center = 984956
set_left_right = 984957
set_merge = 988384
set_none = 984958
set_right = 984959
set_split = 988385
set_square = 988253
set_top_box = 985503
settings_helper = 985710
shaker = 987406
shaker_outline = 987407
shape = 985137
shape_circle_plus = 984669
shape_outline = 985138
shape_oval_plus = 987642
shape_plus = 984213
shape_plus_outline = 990287
shape_polygon_plus = 984670
shape_rectangle_plus = 984671
shape_square_plus = 984672
shape_square_rounded_plus = 988410
share = 984214
share_all = 987636
share_all_outline = 987637
share_circle = 987565
share_off = 986915
share_off_outline = 986916
share_outline = 985394
share_variant = 984215
share_variant_outline = 988436
shark = 989370
shark_fin = 988787
shark_fin_outline = 988788
shark_off = 989371
sheep = 986310
shield = 984216
shield_account = 985231
shield_account_outline = 985618
shield_account_variant = 988583
shield_account_variant_outline = 988584
shield_airplane = 984763
shield_airplane_outline = 986311
shield_alert = 986828
shield_alert_outline = 986829
shield_bug = 988122
shield_bug_outline = 988123
shield_car = 987011
shield_check = 984421
shield_check_outline = 986312
shield_cross = 986313
shield_cross_outline = 986314
shield_crown = 989372
shield_crown_outline = 989373
shield_edit = 987552
shield_edit_outline = 987553
shield_half = 988000
shield_half_full = 984960
shield_home = 984714
shield_home_outline = 986315
shield_key = 986052
shield_key_outline = 986053
shield_link_variant = 986419
shield_link_variant_outline = 986420
shield_lock = 985501
shield_lock_open = 989594
shield_lock_open_outline = 989595
shield_lock_outline = 986316
shield_moon = 989224
shield_moon_outline = 989225
shield_off = 985502
shield_off_outline = 985500
shield_outline = 984217
shield_plus = 985818
shield_plus_outline = 985819
shield_refresh = 983210
shield_refresh_outline = 983520
shield_remove = 985820
shield_remove_outline = 985821
shield_search = 986522
shield_star = 987451
shield_star_outline = 987452
shield_sun = 987229
shield_sun_outline = 987230
shield_sword = 989374
shield_sword_outline = 989375
shield_sync = 987554
shield_sync_outline = 987555
shimmer = 988485
ship_wheel = 985139
shipping_pallet = 989262
shoe_ballet = 988618
shoe_cleat = 988615
shoe_formal = 985927
shoe_heel = 985928
shoe_print = 986618
shoe_sneaker = 988616
shopping = 984218
shopping_music = 984219
shopping_outline = 987605
shopping_search = 987012
shopping_search_outline = 989807
shore = 988409
shovel = 984848
shovel_off = 984849
shower = 985504
shower_head = 985505
shredder = 984220
shuffle = 984221
shuffle_disabled = 984222
shuffle_variant = 984223
shuriken = 988031
sickle = 989376
sigma = 984224
sigma_lower = 984619
sign_caution = 984225
sign_direction = 984961
sign_direction_minus = 987136
sign_direction_plus = 987100
sign_direction_remove = 987101
sign_language = 990029
sign_language_outline = 990030
sign_pole = 988408
sign_real_estate = 987416
sign_text = 984962
sign_yield = 990127
signal = 984226
signal_2g = 984850
signal_3g = 984851
signal_4g = 984852
signal_5g = 985711
signal_cellular_1 = 985276
signal_cellular_2 = 985277
signal_cellular_3 = 985278
signal_cellular_outline = 985279
signal_distance_variant = 986724
signal_hspa = 984853
signal_hspa_plus = 984854
signal_off = 984963
signal_variant = 984586
signature = 986619
signature_freehand = 986620
signature_image = 986621
signature_text = 986622
silo = 990111
silo_outline = 985929
silverware = 984227
silverware_clean = 987102
silverware_fork = 984228
silverware_fork_knife = 985712
silverware_spoon = 984229
silverware_variant = 984230
sim = 984231
sim_alert = 984232
sim_alert_outline = 988627
sim_off = 984233
sim_off_outline = 988628
sim_outline = 988629
simple_icons = 987933
sina_weibo = 985823
sine_wave = 985435
sitemap = 984234
sitemap_outline = 989596
size_l = 988070
size_m = 988069
size_s = 988068
size_xl = 988071
size_xs = 988067
size_xxl = 988072
size_xxs = 988066
size_xxxl = 988073
skate = 986421
skate_off = 984729
skateboard = 988354
skateboarding = 984321
skew_less = 986422
skew_more = 986423
ski = 987908
ski_cross_country = 987909
ski_water = 987910
skip_backward = 984235
skip_backward_outline = 986917
skip_forward = 984236
skip_forward_outline = 986918
skip_next = 984237
skip_next_circle = 984673
skip_next_circle_outline = 984674
skip_next_outline = 986919
skip_previous = 984238
skip_previous_circle = 984675
skip_previous_circle_outline = 984676
skip_previous_outline = 986920
skull = 984716
skull_crossbones = 986054
skull_crossbones_outline = 986055
skull_outline = 986056
skull_scan = 988359
skull_scan_outline = 988360
skype = 984239
skype_business = 984240
slack = 984241
slash_forward = 987103
slash_forward_box = 987104
sledding = 984091
sleep = 984242
sleep_off = 984243
slide = 988581
slope_downhill = 986623
slope_uphill = 986624
slot_machine = 987412
slot_machine_outline = 987413
smart_card = 987325
smart_card_off = 989431
smart_card_off_outline = 989432
smart_card_outline = 987326
smart_card_reader = 987327
smart_card_reader_outline = 987328
smog = 985713
smoke = 989081
smoke_detector = 983954
smoke_detector_alert = 989486
smoke_detector_alert_outline = 989487
smoke_detector_off = 989193
smoke_detector_off_outline = 989194
smoke_detector_outline = 989192
smoke_detector_variant = 989195
smoke_detector_variant_alert = 989488
smoke_detector_variant_off = 989196
smoking = 984244
smoking_off = 984245
smoking_pipe = 988173
smoking_pipe_off = 988200
snail = 988791
snake = 988430
snapchat = 984246
snowboard = 987911
snowflake = 984855
snowflake_alert = 986921
snowflake_check = 989808
snowflake_melt = 987851
snowflake_off = 988387
snowflake_thermometer = 989809
snowflake_variant = 986922
snowman = 984247
snowmobile = 984797
snowshoeing = 989810
soccer = 984248
soccer_field = 985140
social_distance_2_meters = 988537
social_distance_6_feet = 988538
sofa = 984249
sofa_outline = 988525
sofa_single = 988526
sofa_single_outline = 988527
solar_panel = 986523
solar_panel_large = 986524
solar_power = 985714
solar_power_variant = 989811
solar_power_variant_outline = 989812
soldering_iron = 987282
solid = 984717
sony_playstation = 984084
sort = 984250
sort_alphabetical_ascending = 984509
sort_alphabetical_ascending_variant = 987464
sort_alphabetical_descending = 984511
sort_alphabetical_descending_variant = 987465
sort_alphabetical_variant = 984251
sort_ascending = 984252
sort_bool_ascending = 988037
sort_bool_ascending_variant = 988038
sort_bool_descending = 988039
sort_bool_descending_variant = 988040
sort_calendar_ascending = 988487
sort_calendar_descending = 988488
sort_clock_ascending = 988489
sort_clock_ascending_outline = 988490
sort_clock_descending = 988491
sort_clock_descending_outline = 988492
sort_descending = 984253
sort_numeric_ascending = 988041
sort_numeric_ascending_variant = 985357
sort_numeric_descending = 988042
sort_numeric_descending_variant = 985810
sort_numeric_variant = 984254
sort_reverse_variant = 983868
sort_variant = 984255
sort_variant_lock = 986317
sort_variant_lock_open = 986318
sort_variant_off = 989883
sort_variant_remove = 987463
soundbar = 989147
soundcloud = 984256
source_branch = 984620
source_branch_check = 988367
source_branch_minus = 988363
source_branch_plus = 988362
source_branch_refresh = 988365
source_branch_remove = 988364
source_branch_sync = 988366
source_commit = 984856
source_commit_end = 984857
source_commit_end_local = 984858
source_commit_local = 984859
source_commit_next_local = 984860
source_commit_start = 984861
source_commit_start_next_local = 984862
source_fork = 984257
source_merge = 984621
source_pull = 984258
source_repository = 986319
source_repository_multiple = 986320
soy_sauce = 985070
soy_sauce_off = 988156
spa = 986321
spa_outline = 986322
space_invaders = 986057
space_station = 988035
spade = 986725
speaker = 984259
speaker_bluetooth = 985506
speaker_message = 989969
speaker_multiple = 986424
speaker_off = 984260
speaker_pause = 990067
speaker_play = 990066
speaker_stop = 990068
speaker_wireless = 984863
spear = 989253
speedometer = 984261
speedometer_medium = 987013
speedometer_slow = 987014
spellcheck = 984262
sphere = 989524
sphere_off = 989525
spider = 987626
spider_outline = 990325
spider_thread = 987627
spider_web = 986058
spirit_level = 988401
spoon_sugar = 988201
spotify = 984263
spotlight = 984264
spotlight_beam = 984265
spray = 984677
spray_bottle = 985824
sprinkler = 987231
sprinkler_fire = 989597
sprinkler_variant = 987232
sprout = 986726
sprout_outline = 986727
square = 984932
square_circle = 988416
square_circle_outline = 990288
square_edit_outline = 985356
square_medium = 985619
square_medium_outline = 985620
square_off = 987886
square_off_outline = 987887
square_opacity = 989268
square_outline = 984931
square_root = 984964
square_root_box = 985507
square_rounded = 988411
square_rounded_badge = 989703
square_rounded_badge_outline = 989704
square_rounded_outline = 988412
square_small = 985621
square_wave = 988283
squeegee = 985825
ssh = 985280
stack_exchange = 984587
stack_overflow = 984268
stackpath = 983897
stadium = 987129
stadium_outline = 989955
stadium_variant = 984864
stairs = 984269
stairs_box = 988062
stairs_down = 987838
stairs_up = 987837
stamper = 986425
standard_definition = 985071
star = 984270
star_box = 985715
star_box_multiple = 987782
star_box_multiple_outline = 987783
star_box_outline = 985716
star_check = 988518
star_check_outline = 988522
star_circle = 984271
star_circle_outline = 985508
star_cog = 988776
star_cog_outline = 988777
star_crescent = 985465
star_david = 985466
star_face = 985509
star_four_points = 985826
star_four_points_box = 990289
star_four_points_box_outline = 990290
star_four_points_circle = 990291
star_four_points_circle_outline = 990292
star_four_points_outline = 985827
star_four_points_small = 990293
star_half = 983622
star_half_full = 984272
star_minus = 988516
star_minus_outline = 988520
star_off = 984273
star_off_outline = 988507
star_outline = 984274
star_plus = 988515
star_plus_outline = 988519
star_remove = 988517
star_remove_outline = 988521
star_settings = 988778
star_settings_outline = 988779
star_shooting = 988993
star_shooting_outline = 988994
star_three_points = 985828
star_three_points_outline = 985829
state_machine = 987631
steam = 984275
steering = 984276
steering_off = 985358
step_backward = 984277
step_backward_2 = 984278
step_forward = 984279
step_forward_2 = 984280
stethoscope = 984281
sticker = 988004
sticker_alert = 988005
sticker_alert_outline = 988006
sticker_check = 988007
sticker_check_outline = 988008
sticker_circle_outline = 984528
sticker_emoji = 984965
sticker_minus = 988009
sticker_minus_outline = 988010
sticker_outline = 988011
sticker_plus = 988012
sticker_plus_outline = 988013
sticker_remove = 988014
sticker_remove_outline = 988015
sticker_text = 989070
sticker_text_outline = 989071
stocking = 984282
stomach = 987283
stool = 989533
stool_outline = 989534
stop = 984283
stop_circle = 984678
stop_circle_outline = 984679
storage_tank = 989813
storage_tank_outline = 989814
store = 984284
store_24_hour = 984285
store_alert = 989377
store_alert_outline = 989378
store_check = 989379
store_check_outline = 989380
store_clock = 989381
store_clock_outline = 989382
store_cog = 989383
store_cog_outline = 989384
store_edit = 989385
store_edit_outline = 989386
store_marker = 989387
store_marker_outline = 989388
store_minus = 988766
store_minus_outline = 989389
store_off = 989390
store_off_outline = 989391
store_outline = 988001
store_plus = 988767
store_plus_outline = 989392
store_remove = 988768
store_remove_outline = 989393
store_search = 989394
store_search_outline = 989395
store_settings = 989396
store_settings_outline = 989397
storefront = 985031
storefront_check = 990077
storefront_check_outline = 990078
storefront_edit = 990079
storefront_edit_outline = 990080
storefront_minus = 990083
storefront_minus_outline = 990084
storefront_outline = 987329
storefront_plus = 990081
storefront_plus_outline = 990082
storefront_remove = 990085
storefront_remove_outline = 990086
stove = 984286
strategy = 987606
stretch_to_page = 986923
stretch_to_page_outline = 986924
string_lights = 987834
string_lights_off = 987835
subdirectory_arrow_left = 984588
subdirectory_arrow_right = 984589
submarine = 988524
subtitles = 985622
subtitles_outline = 985623
subway = 984748
subway_alert_variant = 986525
subway_variant = 984287
summit = 984966
sun_angle = 989991
sun_angle_outline = 989992
sun_clock = 989815
sun_clock_outline = 989816
sun_compass = 989605
sun_snowflake = 989078
sun_snowflake_variant = 989817
sun_thermometer = 989398
sun_thermometer_outline = 989399
sun_wireless = 989182
sun_wireless_outline = 989183
sunglasses = 984288
surfing = 988998
surround_sound = 984517
surround_sound_2_0 = 985072
surround_sound_2_1 = 988969
surround_sound_3_1 = 985073
surround_sound_5_1 = 985074
surround_sound_5_1_2 = 988970
surround_sound_7_1 = 985075
svg = 984865
swap_horizontal = 984289
swap_horizontal_bold = 986061
swap_horizontal_circle = 987105
swap_horizontal_circle_outline = 987106
swap_horizontal_variant = 985281
swap_vertical = 984290
swap_vertical_bold = 986062
swap_vertical_circle = 987107
swap_vertical_circle_outline = 987108
swap_vertical_variant = 985282
swim = 984291
switch = 984292
sword = 984293
sword_cross = 984967
syllabary_hangul = 987955
syllabary_hiragana = 987956
syllabary_katakana = 987957
syllabary_katakana_halfwidth = 987958
symbol = 988417
symfony = 985830
synagogue = 989956
synagogue_outline = 989957
sync = 984294
sync_alert = 984295
sync_circle = 988024
sync_off = 984296
tab = 984297
tab_minus = 985931
tab_plus = 984924
tab_remove = 985932
tab_search = 989598
tab_unselected = 984298
table = 984299
table_account = 988089
table_alert = 988090
table_arrow_down = 988091
table_arrow_left = 988092
table_arrow_right = 988093
table_arrow_up = 988094
table_border = 985624
table_cancel = 988095
table_chair = 987233
table_check = 988096
table_clock = 988097
table_cog = 988098
table_column = 985141
table_column_plus_after = 984300
table_column_plus_before = 984301
table_column_remove = 984302
table_column_width = 984303
table_edit = 984304
table_eye = 987284
table_eye_off = 988099
table_filter = 990092
table_furniture = 984508
table_headers_eye = 987677
table_headers_eye_off = 987678
table_heart = 988100
table_key = 988101
table_large = 984305
table_large_plus = 987015
table_large_remove = 987016
table_lock = 988102
table_merge_cells = 985510
table_minus = 988103
table_multiple = 988104
table_network = 988105
table_of_contents = 985142
table_off = 988106
table_picnic = 988995
table_pivot = 989244
table_plus = 985717
table_question = 989985
table_refresh = 988064
table_remove = 985718
table_row = 985143
table_row_height = 984306
table_row_plus_after = 984307
table_row_plus_before = 984308
table_row_remove = 984309
table_search = 985359
table_settings = 985144
table_split_cell = 988202
table_star = 988107
table_sync = 988065
table_tennis = 986728
tablet = 984310
tablet_cellphone = 985511
tablet_dashboard = 986830
taco = 984930
tag = 984313
tag_arrow_down = 988971
tag_arrow_down_outline = 988972
tag_arrow_left = 988973
tag_arrow_left_outline = 988974
tag_arrow_right = 988975
tag_arrow_right_outline = 988976
tag_arrow_up = 988977
tag_arrow_up_outline = 988978
tag_check = 989818
tag_check_outline = 989819
tag_edit = 990364
tag_edit_outline = 990365
tag_faces = 984314
tag_heart = 984715
tag_heart_outline = 986063
tag_hidden = 990326
tag_minus = 985360
tag_minus_outline = 987679
tag_multiple = 984315
tag_multiple_outline = 987895
tag_off = 987680
tag_off_outline = 987681
tag_outline = 984316
tag_plus = 984866
tag_plus_outline = 987682
tag_remove = 984867
tag_remove_outline = 987683
tag_search = 989447
tag_search_outline = 989448
tag_text = 987684
tag_text_outline = 984317
tailwind = 988159
tally_mark_1 = 989884
tally_mark_2 = 989885
tally_mark_3 = 989886
tally_mark_4 = 989887
tally_mark_5 = 989888
tangram = 984312
tank = 986426
tanker_truck = 987109
tape_drive = 988895
tape_measure = 985933
target = 984318
target_account = 986064
target_variant = 985719
taxi = 984319
tea = 986526
tea_outline = 986527
teamviewer = 984320
teddy_bear = 989435
telescope = 985934
television = 984322
television_ambient_light = 987990
television_box = 985145
television_classic = 985076
television_classic_off = 985146
television_guide = 984323
television_off = 985147
television_pause = 987017
television_play = 986831
television_shimmer = 987408
television_speaker = 989979
television_speaker_off = 989980
television_stop = 987018
temperature_celsius = 984324
temperature_fahrenheit = 984325
temperature_kelvin = 984326
temple_buddhist = 989958
temple_buddhist_outline = 989959
temple_hindu = 989960
temple_hindu_outline = 989961
tennis = 986528
tennis_ball = 984327
tennis_ball_outline = 990303
tent = 984328
terraform = 987234
terrain = 984329
test_tube = 984680
test_tube_empty = 985361
test_tube_off = 985362
text = 985512
text_account = 988528
text_box = 983578
text_box_check = 986790
text_box_check_outline = 986791
text_box_edit = 989820
text_box_edit_outline = 989821
text_box_minus = 986792
text_box_minus_outline = 986793
text_box_multiple = 985783
text_box_multiple_outline = 985784
text_box_outline = 985581
text_box_plus = 986794
text_box_plus_outline = 986795
text_box_remove = 986796
text_box_remove_outline = 986797
text_box_search = 986798
text_box_search_outline = 986799
text_long = 985514
text_recognition = 987453
text_search = 988088
text_search_variant = 989822
text_shadow = 984681
text_short = 985513
texture = 984332
texture_box = 987110
theater = 984333
theme_light_dark = 984334
thermometer = 984335
thermometer_alert = 986625
thermometer_auto = 989967
thermometer_bluetooth = 989333
thermometer_check = 989823
thermometer_chevron_down = 986626
thermometer_chevron_up = 986627
thermometer_high = 987330
thermometer_lines = 984336
thermometer_low = 987331
thermometer_minus = 986628
thermometer_off = 988465
thermometer_plus = 986629
thermometer_probe = 989995
thermometer_probe_off = 989996
thermometer_water = 989824
thermostat = 983955
thermostat_auto = 989975
thermostat_box = 985233
thermostat_box_auto = 989976
thermostat_cog = 990336
thought_bubble = 985078
thought_bubble_outline = 985079
thumb_down = 984337
thumb_down_outline = 984338
thumb_up = 984339
thumb_up_outline = 984340
thumbs_up_down = 984341
thumbs_up_down_outline = 989460
ticket = 984342
ticket_account = 984343
ticket_confirmation = 984344
ticket_confirmation_outline = 988074
ticket_outline = 985363
ticket_percent = 984868
ticket_percent_outline = 988203
tie = 984345
tilde = 984869
tilde_off = 989427
timelapse = 984346
timeline = 986065
timeline_alert = 987029
timeline_alert_outline = 987032
timeline_check = 988466
timeline_check_outline = 988467
timeline_clock = 987643
timeline_clock_outline = 987644
timeline_minus = 988468
timeline_minus_outline = 988469
timeline_outline = 986066
timeline_plus = 987030
timeline_plus_outline = 987031
timeline_question = 987033
timeline_question_outline = 987034
timeline_remove = 988470
timeline_remove_outline = 988471
timeline_text = 986067
timeline_text_outline = 986068
timer = 988075
timer_10 = 984348
timer_3 = 984349
timer_alert = 989900
timer_alert_outline = 989901
timer_cancel = 989902
timer_cancel_outline = 989903
timer_check = 989904
timer_check_outline = 989905
timer_cog = 989477
timer_cog_outline = 989478
timer_edit = 989906
timer_edit_outline = 989907
timer_lock = 989908
timer_lock_open = 989909
timer_lock_open_outline = 989910
timer_lock_outline = 989911
timer_marker = 989912
timer_marker_outline = 989913
timer_minus = 989914
timer_minus_outline = 989915
timer_music = 989916
timer_music_outline = 989917
timer_off = 988076
timer_off_outline = 984350
timer_outline = 984347
timer_pause = 989918
timer_pause_outline = 989919
timer_play = 989920
timer_play_outline = 989921
timer_plus = 989922
timer_plus_outline = 989923
timer_refresh = 989924
timer_refresh_outline = 989925
timer_remove = 989926
timer_remove_outline = 989927
timer_sand = 984351
timer_sand_complete = 989599
timer_sand_empty = 984749
timer_sand_full = 984972
timer_sand_paused = 989600
timer_settings = 989475
timer_settings_outline = 989476
timer_star = 989928
timer_star_outline = 989929
timer_stop = 989930
timer_stop_outline = 989931
timer_sync = 989932
timer_sync_outline = 989933
timetable = 984352
tire = 989334
toaster = 987235
toaster_off = 987575
toaster_oven = 986323
toggle_switch = 984353
toggle_switch_off = 984354
toggle_switch_off_outline = 985625
toggle_switch_outline = 985626
toggle_switch_variant = 989733
toggle_switch_variant_off = 989734
toilet = 985515
toolbox = 985516
toolbox_outline = 985517
tools = 987236
tooltip = 984355
tooltip_account = 983052
tooltip_cellphone = 989243
tooltip_check = 988508
tooltip_check_outline = 988509
tooltip_edit = 984356
tooltip_edit_outline = 987845
tooltip_image = 984357
tooltip_image_outline = 986069
tooltip_minus = 988510
tooltip_minus_outline = 988511
tooltip_outline = 984358
tooltip_plus = 986070
tooltip_plus_outline = 984359
tooltip_question = 990138
tooltip_question_outline = 990139
tooltip_remove = 988512
tooltip_remove_outline = 988513
tooltip_text = 984360
tooltip_text_outline = 986071
tooth = 985283
tooth_outline = 984361
toothbrush = 987433
toothbrush_electric = 987436
toothbrush_paste = 987434
torch = 988678
tortoise = 986427
toslink = 987832
touch_text_outline = 990304
tournament = 985518
tow_truck = 985148
tower_beach = 984705
tower_fire = 984706
town_hall = 989301
toy_brick = 987784
toy_brick_marker = 987785
toy_brick_marker_outline = 987786
toy_brick_minus = 987787
toy_brick_minus_outline = 987788
toy_brick_outline = 987789
toy_brick_plus = 987790
toy_brick_plus_outline = 987791
toy_brick_remove = 987792
toy_brick_remove_outline = 987793
toy_brick_search = 987794
toy_brick_search_outline = 987795
track_light = 985364
track_light_off = 989953
trackpad = 985080
trackpad_lock = 985395
tractor = 985234
tractor_variant = 988356
trademark = 985720
traffic_cone = 988028
traffic_light = 984363
traffic_light_outline = 989226
train = 984364
train_bus = 990407
train_car = 986072
train_car_autorack = 989997
train_car_box = 989998
train_car_box_full = 989999
train_car_box_open = 990000
train_car_caboose = 990001
train_car_centerbeam = 990002
train_car_centerbeam_full = 990003
train_car_container = 990004
train_car_flatbed = 990005
train_car_flatbed_car = 990006
train_car_flatbed_tank = 990007
train_car_gondola = 990008
train_car_gondola_full = 990009
train_car_hopper = 990010
train_car_hopper_covered = 990011
train_car_hopper_full = 990012
train_car_intermodal = 990013
train_car_passenger = 988979
train_car_passenger_door = 988980
train_car_passenger_door_open = 988981
train_car_passenger_variant = 988982
train_car_tank = 990014
train_variant = 985284
tram = 984365
tram_side = 987111
transcribe = 984366
transcribe_close = 984367
transfer = 987237
transfer_down = 986529
transfer_left = 986530
transfer_right = 984368
transfer_up = 986531
transit_connection = 986428
transit_connection_horizontal = 988486
transit_connection_variant = 986429
transit_detour = 987019
transit_skip = 988437
transit_transfer = 984750
transition = 985365
transition_masked = 985366
translate = 984522
translate_off = 986630
translate_variant = 990105
transmission_tower = 986430
transmission_tower_export = 989484
transmission_tower_import = 989485
transmission_tower_off = 989661
trash_can = 985721
trash_can_outline = 985722
tray = 987796
tray_alert = 987797
tray_arrow_down = 983328
tray_arrow_up = 983325
tray_full = 987798
tray_minus = 987799
tray_plus = 987800
tray_remove = 987801
treasure_chest = 984870
treasure_chest_outline = 990327
tree = 984369
tree_outline = 986729
trello = 984370
trending_down = 984371
trending_neutral = 984372
trending_up = 984373
triangle = 984374
triangle_down = 990294
triangle_down_outline = 990295
triangle_outline = 984375
triangle_small_down = 989705
triangle_small_up = 989706
triangle_wave = 988284
triforce = 986073
trophy = 984376
trophy_award = 984377
trophy_broken = 986532
trophy_outline = 984378
trophy_variant = 984379
trophy_variant_outline = 984380
truck = 984381
truck_alert = 989662
truck_alert_outline = 989663
truck_cargo_container = 989400
truck_check = 986324
truck_check_outline = 987802
truck_delivery = 984382
truck_delivery_outline = 987803
truck_fast = 984968
truck_fast_outline = 987804
truck_flatbed = 989329
truck_minus = 989614
truck_minus_outline = 989629
truck_off_road = 990366
truck_off_road_off = 990367
truck_outline = 987805
truck_plus = 989613
truck_plus_outline = 989628
truck_remove = 989615
truck_remove_outline = 989630
truck_snowflake = 989606
truck_trailer = 984871
trumpet = 987286
tshirt_crew = 985723
tshirt_crew_outline = 984383
tshirt_v = 985724
tshirt_v_outline = 984384
tsunami = 989825
tumble_dryer = 985367
tumble_dryer_alert = 987578
tumble_dryer_off = 987579
tune = 984622
tune_variant = 988482
tune_vertical = 984682
tune_vertical_variant = 988483
tunnel = 989245
tunnel_outline = 989246
turbine = 989826
turkey = 988955
turnstile = 986325
turnstile_outline = 986326
turtle = 986327
twitch = 984387
twitter = 984388
two_factor_authentication = 985519
typewriter = 986925
ubisoft = 986074
ubuntu = 984392
ufo = 987332
ufo_outline = 987333
ultra_high_definition = 985081
umbraco = 984393
umbrella = 984394
umbrella_beach = 989322
umbrella_beach_outline = 989323
umbrella_closed = 985520
umbrella_closed_outline = 988130
umbrella_closed_variant = 988129
umbrella_outline = 984395
undo = 984396
undo_variant = 984397
unfold_less_horizontal = 984398
unfold_less_vertical = 984928
unfold_more_horizontal = 984399
unfold_more_vertical = 984929
ungroup = 984400
unicode = 986832
unicorn = 988610
unicorn_variant = 988611
unicycle = 988645
unity = 984751
unreal = 985521
update = 984752
upload = 984402
upload_lock = 988019
upload_lock_outline = 988020
upload_multiple = 985149
upload_network = 984822
upload_network_outline = 986328
upload_off = 987334
upload_off_outline = 987335
upload_outline = 986631
usb = 984403
usb_c_port = 990399
usb_flash_drive = 987806
usb_flash_drive_outline = 987807
usb_port = 987632
vacuum = 989601
vacuum_outline = 989602
valve = 987238
valve_closed = 987239
valve_open = 987240
van_passenger = 985082
van_utility = 985083
vanish = 985084
vanish_quarter = 988500
vanity_light = 987617
variable = 985831
variable_box = 987409
vector_arrange_above = 984404
vector_arrange_below = 984405
vector_bezier = 985832
vector_circle = 984406
vector_circle_variant = 984407
vector_combine = 984408
vector_curve = 984409
vector_difference = 984410
vector_difference_ab = 984411
vector_difference_ba = 984412
vector_ellipse = 985235
vector_intersection = 984413
vector_line = 984414
vector_link = 987112
vector_point = 983492
vector_point_edit = 985576
vector_point_minus = 990072
vector_point_plus = 990073
vector_point_select = 984415
vector_polygon = 984416
vector_polygon_variant = 989270
vector_polyline = 984417
vector_polyline_edit = 987685
vector_polyline_minus = 987686
vector_polyline_plus = 987687
vector_polyline_remove = 987688
vector_radius = 984906
vector_rectangle = 984518
vector_selection = 984418
vector_square = 983041
vector_square_close = 989271
vector_square_edit = 989401
vector_square_minus = 989402
vector_square_open = 989272
vector_square_plus = 989403
vector_square_remove = 989404
vector_triangle = 984419
vector_union = 984420
vhs = 985627
vibrate = 984422
vibrate_off = 986329
video = 984423
video_2d = 989724
video_3d = 985085
video_3d_off = 988121
video_3d_variant = 986833
video_4k_box = 985150
video_account = 985369
video_box = 983293
video_box_off = 983294
video_check = 987241
video_check_outline = 987242
video_high_definition = 988462
video_image = 985370
video_input_antenna = 985151
video_input_component = 985152
video_input_hdmi = 985153
video_input_scart = 987020
video_input_svideo = 985154
video_marker = 989609
video_marker_outline = 989610
video_minus = 985522
video_minus_outline = 983738
video_off = 984424
video_off_outline = 986075
video_outline = 986076
video_plus = 985523
video_plus_outline = 983507
video_stabilization = 985371
video_standard_definition = 990368
video_switch = 984425
video_switch_outline = 984976
video_vintage = 985628
video_wireless = 986834
video_wireless_outline = 986835
view_agenda = 984426
view_agenda_outline = 987608
view_array = 984427
view_array_outline = 988293
view_carousel = 984428
view_carousel_outline = 988294
view_column = 984429
view_column_outline = 988295
view_comfy = 986730
view_comfy_outline = 988296
view_compact = 986731
view_compact_outline = 986732
view_dashboard = 984430
view_dashboard_edit = 989511
view_dashboard_edit_outline = 989512
view_dashboard_outline = 985629
view_dashboard_variant = 985155
view_dashboard_variant_outline = 988297
view_day = 984431
view_day_outline = 988298
view_gallery = 989320
view_gallery_outline = 989321
view_grid = 984432
view_grid_compact = 990305
view_grid_outline = 987609
view_grid_plus = 987021
view_grid_plus_outline = 987610
view_headline = 984433
view_list = 984434
view_list_outline = 988299
view_module = 984435
view_module_outline = 988300
view_parallel = 984872
view_parallel_outline = 988301
view_quilt = 984436
view_quilt_outline = 988302
view_sequential = 984873
view_sequential_outline = 988303
view_split_horizontal = 986059
view_split_vertical = 986060
view_stream = 984437
view_stream_outline = 988304
view_week = 984438
view_week_outline = 988305
vimeo = 984439
violin = 984591
virtual_reality = 985236
virus = 988086
virus_off = 989409
virus_off_outline = 989410
virus_outline = 988087
vlc = 984444
voicemail = 984445
volcano = 989827
volcano_outline = 989828
volleyball = 985524
volume_equal = 989968
volume_high = 984446
volume_low = 984447
volume_medium = 984448
volume_minus = 984926
volume_mute = 984927
volume_off = 984449
volume_plus = 984925
volume_source = 987424
volume_variant_off = 986632
volume_vibrate = 987425
vote = 985631
vote_outline = 985632
vpn = 984450
vuejs = 985156
vuetify = 986733
walk = 984451
wall = 985086
wall_fire = 989713
wall_sconce = 985372
wall_sconce_flat = 985373
wall_sconce_flat_outline = 989129
wall_sconce_flat_variant = 984092
wall_sconce_flat_variant_outline = 989130
wall_sconce_outline = 989131
wall_sconce_round = 984904
wall_sconce_round_outline = 989132
wall_sconce_round_variant = 985374
wall_sconce_round_variant_outline = 989133
wallet = 984452
wallet_bifold = 990296
wallet_bifold_outline = 990297
wallet_giftcard = 984453
wallet_membership = 984454
wallet_outline = 986077
wallet_plus = 987022
wallet_plus_outline = 987023
wallet_travel = 984455
wallpaper = 986633
wan = 984456
wardrobe = 987024
wardrobe_outline = 987025
warehouse = 987009
washing_machine = 984874
washing_machine_alert = 987580
washing_machine_off = 987581
watch = 984457
watch_export = 984458
watch_export_variant = 985237
watch_import = 984459
watch_import_variant = 985238
watch_variant = 985239
watch_vibrate = 984753
watch_vibrate_off = 986330
water = 984460
water_alert = 988418
water_alert_outline = 988419
water_boiler = 987026
water_boiler_alert = 987571
water_boiler_auto = 990104
water_boiler_off = 987572
water_check = 988420
water_check_outline = 988421
water_circle = 989190
water_minus = 988422
water_minus_outline = 988423
water_off = 984461
water_off_outline = 988424
water_opacity = 989269
water_outline = 986634
water_percent = 984462
water_percent_alert = 988425
water_plus = 988426
water_plus_outline = 988427
water_polo = 987808
water_pump = 984463
water_pump_off = 987027
water_remove = 988428
water_remove_outline = 988429
water_sync = 989126
water_thermometer = 989829
water_thermometer_outline = 989830
water_well = 987243
water_well_outline = 987244
waterfall = 989257
watering_can = 988289
watering_can_outline = 988290
watermark = 984594
wave = 986926
wave_arrow_down = 990384
wave_arrow_up = 990385
wave_undercurrent = 990400
waveform = 988285
waves = 984973
waves_arrow_left = 989273
waves_arrow_right = 989274
waves_arrow_up = 989275
waze = 986078
weather_cloudy = 984464
weather_cloudy_alert = 986927
weather_cloudy_arrow_right = 986734
weather_cloudy_clock = 989430
weather_dust = 990042
weather_fog = 984465
weather_hail = 984466
weather_hazy = 986928
weather_hurricane = 985240
weather_hurricane_outline = 990328
weather_lightning = 984467
weather_lightning_rainy = 984702
weather_night = 984468
weather_night_partly_cloudy = 986929
weather_partly_cloudy = 984469
weather_partly_lightning = 986930
weather_partly_rainy = 986931
weather_partly_snowy = 986932
weather_partly_snowy_rainy = 986933
weather_pouring = 984470
weather_rainy = 984471
weather_snowy = 984472
weather_snowy_heavy = 986934
weather_snowy_rainy = 984703
weather_sunny = 984473
weather_sunny_alert = 986935
weather_sunny_off = 988388
weather_sunset = 984474
weather_sunset_down = 984475
weather_sunset_up = 984476
weather_tornado = 986936
weather_windy = 984477
weather_windy_variant = 984478
web = 984479
web_box = 987028
web_cancel = 989072
web_check = 984969
web_clock = 987722
web_minus = 987296
web_off = 985742
web_plus = 983091
web_refresh = 989073
web_remove = 984401
web_sync = 989074
webcam = 984480
webcam_off = 988983
webhook = 984623
webpack = 984875
webrtc = 987720
wechat = 984593
weight = 984481
weight_gram = 986431
weight_kilogram = 984482
weight_lifter = 987485
weight_pound = 985525
whatsapp = 984483
wheel_barrow = 988402
wheelchair = 989831
wheelchair_accessibility = 984484
whistle = 985526
whistle_outline = 987836
white_balance_auto = 984485
white_balance_incandescent = 984486
white_balance_iridescent = 984487
white_balance_sunny = 984488
widgets = 984876
widgets_outline = 987989
wifi = 984489
wifi_alert = 988853
wifi_arrow_down = 988854
wifi_arrow_left = 988855
wifi_arrow_left_right = 988856
wifi_arrow_right = 988857
wifi_arrow_up = 988858
wifi_arrow_up_down = 988859
wifi_cancel = 988860
wifi_check = 988861
wifi_cog = 988862
wifi_lock = 988863
wifi_lock_open = 988864
wifi_marker = 988865
wifi_minus = 988866
wifi_off = 984490
wifi_plus = 988867
wifi_refresh = 988868
wifi_remove = 988869
wifi_settings = 988870
wifi_star = 986635
wifi_strength_1 = 985375
wifi_strength_1_alert = 985376
wifi_strength_1_lock = 985377
wifi_strength_1_lock_open = 988875
wifi_strength_2 = 985378
wifi_strength_2_alert = 985379
wifi_strength_2_lock = 985380
wifi_strength_2_lock_open = 988876
wifi_strength_3 = 985381
wifi_strength_3_alert = 985382
wifi_strength_3_lock = 985383
wifi_strength_3_lock_open = 988877
wifi_strength_4 = 985384
wifi_strength_4_alert = 985385
wifi_strength_4_lock = 985386
wifi_strength_4_lock_open = 988878
wifi_strength_alert_outline = 985387
wifi_strength_lock_open_outline = 988879
wifi_strength_lock_outline = 985388
wifi_strength_off = 985389
wifi_strength_off_outline = 985390
wifi_strength_outline = 985391
wifi_sync = 988871
wikipedia = 984492
wind_power = 989832
wind_power_outline = 989833
wind_turbine = 986533
wind_turbine_alert = 989611
wind_turbine_check = 989612
window_close = 984493
window_closed = 984494
window_closed_variant = 987611
window_maximize = 984495
window_minimize = 984496
window_open = 984497
window_open_variant = 987612
window_restore = 984498
window_shutter = 987420
window_shutter_alert = 987421
window_shutter_auto = 990115
window_shutter_cog = 989834
window_shutter_open = 987422
window_shutter_settings = 989835
windsock = 988666
wiper = 985833
wiper_wash = 986534
wiper_wash_alert = 989407
wizard_hat = 988279
wordpress = 984500
wrap = 984502
wrap_disabled = 986079
wrench = 984503
wrench_check = 990095
wrench_check_outline = 990096
wrench_clock = 989603
wrench_clock_outline = 990099
wrench_cog = 990097
wrench_cog_outline = 990098
wrench_outline = 986080
xamarin = 985157
xml = 984512
xmpp = 985087
yahoo = 985935
yeast = 984513
yin_yang = 984704
yoga = 987516
youtube = 984515
youtube_gaming = 985160
youtube_studio = 985159
youtube_subscription = 986432
youtube_tv = 984136
yurt = 988438
z_wave = 985834
zend = 985835
zigbee = 986433
zip_box = 984516
zip_box_outline = 987130
zip_disk = 985635
zodiac_aquarius = 985725
zodiac_aries = 985726
zodiac_cancer = 985727
zodiac_capricorn = 985728
zodiac_gemini = 985729
zodiac_leo = 985730
zodiac_libra = 985731
zodiac_pisces = 985732
zodiac_sagittarius = 985733
zodiac_scorpio = 985734
zodiac_taurus = 985735
zodiac_virgo = 985736
